@@ -4,21 +4,14 @@
 """Atomic Simulation Environment."""
 
 import sys
-from distutils.version import LooseVersion
-import numpy as np
 
 
 if sys.version_info[0] == 2:
     raise ImportError('ASE requires Python3. This is Python2.')
 
 
-if LooseVersion(np.__version__) < '1.9':
-    raise ImportError(
-        'ASE needs NumPy-1.9.0 or later. You have: %s' % np.__version__)
-
-
 __all__ = ['Atoms', 'Atom']
-__version__ = '3.21.1'
+__version__ = '3.22.1'
 
 
 from ase.atom import Atom
