@@ -6,7 +6,6 @@
 This module defines the central object in the ASE package: the Atoms
 object.
 """
-
 import copy
 import numbers
 from math import cos, sin, pi
@@ -16,11 +15,10 @@ import numpy as np
 import ase.units as units
 from ase.atom import Atom
 from ase.cell import Cell
-from ase.constraints import (FixConstraint, FixBondLengths, FixLinearTriatomic,
-                             voigt_6_to_full_3x3_stress,
-                             full_3x3_to_voigt_6_stress)
+from ase.stress import voigt_6_to_full_3x3_stress, full_3x3_to_voigt_6_stress
 from ase.data import atomic_masses, atomic_masses_common
-from ase.geometry import wrap_positions, find_mic, get_angles, get_distances, get_dihedrals
+from ase.geometry import (wrap_positions, find_mic, get_angles, get_distances,
+                          get_dihedrals)
 from ase.symbols import Symbols, symbols2numbers
 from ase.utils import deprecated
 
@@ -942,9 +940,11 @@ class Atoms:
             from ase.constraints import dict2constraint
             constraints = [dict2constraint(d) for d in constraints]
 
+        info = dct.pop('info', None)
+
         atoms = cls(constraint=constraints,
                     celldisp=dct.pop('celldisp', None),
-                    info=dct.pop('info', None), **kw)
+                    info=info, **kw)
         natoms = len(atoms)
 
         # Some arrays are named differently from the atoms __init__ keywords.
@@ -1107,13 +1107,12 @@ class Atoms:
         conadd = []
         # Constraints need to be deepcopied, but only the relevant ones.
         for con in copy.deepcopy(self.constraints):
-            if isinstance(con, (FixConstraint, FixBondLengths,
-                                FixLinearTriatomic)):
-                try:
-                    con.index_shuffle(self, i)
-                    conadd.append(con)
-                except IndexError:
-                    pass
+            try:
+                con.index_shuffle(self, i)
+            except (IndexError, NotImplementedError):
+                pass
+            else:
+                conadd.append(con)
 
         atoms = self.__class__(cell=self.cell, pbc=self.pbc, info=self.info,
                                # should be communicated to the slice as well
@@ -1556,7 +1555,6 @@ class Atoms:
 
         return get_dihedrals(v0, v1, v2, cell=cell, pbc=pbc)
 
-
     def _masked_rotate(self, center, axis, diff, mask):
         # do rotation of subgroup by copying it to temporary atoms object
         # and then rotating that
@@ -1883,7 +1881,7 @@ class Atoms:
         """Get the temperature in Kelvin."""
         dof = len(self) * 3
         for constraint in self._constraints:
-            dof -= constraint.removed_dof
+            dof -= constraint.get_removed_dof(self)
         ekin = self.get_kinetic_energy()
         return 2 * ekin / (dof * units.kB)
 
