@@ -17,6 +17,7 @@ import numpy as np
 from ase.units import eV, Ang
 from ase.calculators.calculator import FileIOCalculator, ReadError
 
+
 class GULPOptimizer:
     def __init__(self, atoms, calc):
         self.atoms = atoms
@@ -75,7 +76,7 @@ class GULP(FileIOCalculator):
         self.conditions = conditions
         self.library_check()
         self.atom_types = []
-        self.fractional_coordinates = None # GULP prints the fractional coordinates before the Final lattice vectors so they need to be stored and then atoms positions need to be set after we get the Final lattice vectors
+        self.fractional_coordinates = None  # GULP prints the fractional coordinates before the Final lattice vectors so they need to be stored and then atoms positions need to be set after we get the Final lattice vectors
 
     def write_input(self, atoms, properties=None, system_changes=None):
         FileIOCalculator.write_input(self, atoms, properties, system_changes)
@@ -114,16 +115,16 @@ class GULP(FileIOCalculator):
         if p.options:
             for t in p.options:
                 s += '%s\n' % t
-        with open(self.prefix + '.gin', 'w') as f:
-            f.write(s)
+        with open(self.prefix + '.gin', 'w') as fd:
+            fd.write(s)
 
     def read_results(self):
         FileIOCalculator.read(self, self.label)
         if not os.path.isfile(self.label + '.got'):
             raise ReadError
 
-        with open(self.label + '.got') as f:
-            lines = f.readlines()
+        with open(self.label + '.got') as fd:
+            lines = fd.readlines()
 
         cycles = -1
         self.optimized = None
@@ -208,22 +209,22 @@ class GULP(FileIOCalculator):
                 self.atoms.set_positions(positions)
 
             elif line.find('Final stress tensor components') != -1:
-                res=[0.,0.,0.,0.,0.,0.]
+                res = [0., 0., 0., 0., 0., 0.]
                 for j in range(3):
-                    var=lines[i+j+3].split()[1]
-                    res[j]=float(var)
-                    var=lines[i+j+3].split()[3]
-                    res[j+3]=float(var)
-                stress=np.array(res)
-                self.results['stress']=stress
+                    var = lines[i+j+3].split()[1]
+                    res[j] = float(var)
+                    var = lines[i+j+3].split()[3]
+                    res[j+3] = float(var)
+                stress = np.array(res)
+                self.results['stress'] = stress
 
             elif line.find('Final Cartesian lattice vectors') != -1:
-                lattice_vectors = np.zeros((3,3))
+                lattice_vectors = np.zeros((3, 3))
                 s = i + 2
                 for j in range(s, s+3):
-                    temp=lines[j].split()
+                    temp = lines[j].split()
                     for k in range(3):
-                        lattice_vectors[j-s][k]=float(temp[k])
+                        lattice_vectors[j-s][k] = float(temp[k])
                 self.atoms.set_cell(lattice_vectors)
                 if self.fractional_coordinates is not None:
                     self.fractional_coordinates = np.array(self.fractional_coordinates)
@@ -260,6 +261,7 @@ class GULP(FileIOCalculator):
                 raise RuntimeError("Be sure to have set correctly $GULP_LIB "
                                    "or to have the force field library.")
 
+
 class Conditions:
     """Atomic labels for the GULP calculator.
 
