@@ -24,12 +24,10 @@ import time
 import subprocess
 import re
 import warnings
-from distutils.version import LooseVersion
 import numpy as np
 from ase.geometry import cell_to_cellpar
 from ase.calculators.calculator import (FileIOCalculator, Calculator, equal,
-                                        all_changes, kptdensity2monkhorstpack,
-                                        PropertyNotImplementedError)
+                                        all_changes, kptdensity2monkhorstpack)
 from ase.calculators.openmx.parameters import OpenMXParameters
 from ase.calculators.openmx.default_settings import default_dictionary
 from ase.calculators.openmx.reader import read_openmx, get_file_name
@@ -334,8 +332,8 @@ class OpenMX(FileIOCalculator):
             # self.clean()
         except RuntimeError as e:
             try:
-                with open(get_file_name('.log'), 'r') as f:
-                    lines = f.readlines()
+                with open(get_file_name('.log'), 'r') as fd:
+                    lines = fd.readlines()
                 debug_lines = 10
                 print('##### %d last lines of the OpenMX output' % debug_lines)
                 for line in lines[-20:]:
@@ -373,9 +371,9 @@ class OpenMX(FileIOCalculator):
         self.prind('Reading input file'+self.label)
         filename = get_file_name('.dat', self.label)
         if not nohup:
-            with open(filename, 'r') as f:
+            with open(filename, 'r') as fd:
                 while True:
-                    line = f.readline()
+                    line = fd.readline()
                     print(line.strip())
                     if not line:
                         break
@@ -503,24 +501,8 @@ class OpenMX(FileIOCalculator):
         if atoms is None:
             atoms = self.atoms
 
-        def check_version():
-            if LooseVersion(self.version) < '3.8':
-                raise PropertyNotImplementedError(
-                    'Version lower than 3.8 does not support stress '
-                    'calculation.  Your version is %s' % self.version)
-
-        # We may not yet know what version we are, since that can only
-        # be seen from the output
-        if getattr(self, 'version', None) is not None:
-            check_version()
-
-        try:
-            stress = self.get_property('stress', atoms)
-        except PropertyNotImplementedError:
-            # Now we know the version number, either we raise version
-            # error or the original error (the latter should not happen)
-            check_version()
-            raise
+        # Note: Stress is only supported from OpenMX 3.8+.
+        stress = self.get_property('stress', atoms)
 
         return stress
 
@@ -716,11 +698,11 @@ class OpenMX(FileIOCalculator):
         while not os.path.isfile(file):
             self.prind('Waiting for %s to come out' % file)
             time.sleep(5)
-        with open(file, 'r') as f:
+        with open(file, 'r') as fd:
             while running(**args):
-                f.seek(last_position)
-                new_data = f.read()
-                prev_position = f.tell()
+                fd.seek(last_position)
+                new_data = fd.read()
+                prev_position = fd.tell()
                 # self.prind('pos', prev_position != last_position)
                 if prev_position != last_position:
                     if not self.nohup:
