@@ -132,8 +132,8 @@ class Psi4(Calculator):
         if not os.path.isfile(filename):
             raise ReadError('Could not find the psi4 output file: ' + filename)
 
-        with open(filename, 'r') as f:
-            txt = f.read()
+        with open(filename, 'r') as fd:
+            txt = fd.read()
         if '!ASE Information\n' not in txt:
             raise Exception('The output file {} could not be read because '
                             'the file does not contain the "!ASE Information"'
@@ -193,9 +193,9 @@ class Psi4(Calculator):
         # dump the calculator info to the psi4 file
         save_atoms = self.atoms.copy()
         # use io.write to encode atoms
-        with StringIO() as f:
-            io.write(f, save_atoms, format='json')
-            json_atoms = f.getvalue()
+        with StringIO() as fd:
+            io.write(fd, save_atoms, format='json')
+            json_atoms = fd.getvalue()
         # convert forces to list for json storage
         save_results = self.results.copy()
         if 'forces' in save_results:
