@@ -1,9 +1,16 @@
-import os
+"""TAB-completion sub-command and update helper funtion.
+
+Run this when ever options are changed::
+
+    python3 -m ase.cli.completion
+"""
+
 import sys
+from pathlib import Path
+from typing import List, Dict, Tuple
 
 # Path of the complete.py script:
-my_dir, _ = os.path.split(os.path.realpath(__file__))
-filename = os.path.join(my_dir, 'complete.py')
+path = Path(__file__).with_name('complete.py')
 
 
 class CLICommand:
@@ -11,8 +18,7 @@ class CLICommand:
 
     Will show the command that needs to be added to your '~/.bashrc file.
     """
-    cmd = ('complete -o default -C "{py} {filename}" ase'
-           .format(py=sys.executable, filename=filename))
+    cmd = f'complete -o default -C "{sys.executable} {path}" ase'
 
     @staticmethod
     def add_arguments(parser):
@@ -24,19 +30,20 @@ class CLICommand:
         print(cmd)
 
 
-def update(filename, commands):
-    """Update commands dict.
+def update(path: Path,
+           subcommands: List[Tuple[str, str]],
+           test: bool = False) -> None:
+    """Update commands dict in complete.py.
 
-    Run this when ever options are changed::
-
-        python3 -m ase.cli.complete
+    Use test=True to test that no changes are needed.
 
+    Refactor with care!  This function is also used by GPAW.
     """
 
     import textwrap
-    from ase.utils import import_module
+    from importlib import import_module
 
-    dct = {}  # Dict[str, List[str]]
+    dct: Dict[str, List[str]] = {}
 
     class Subparser:
         def __init__(self, command):
@@ -50,9 +57,9 @@ def update(filename, commands):
         def add_mutually_exclusive_group(self, required=False):
             return self
 
-    for command, module_name in commands:
+    for command, module_name in subcommands:
         module = import_module(module_name)
-        module.CLICommand.add_arguments(Subparser(command))
+        module.CLICommand.add_arguments(Subparser(command))  # type: ignore
 
     txt = 'commands = {'
     for command, opts in sorted(dct.items()):
@@ -65,17 +72,27 @@ def update(filename, commands):
         else:
             txt += '],'
     txt = txt[:-1] + '}\n'
-    with open(filename) as fd:
+
+    with path.open() as fd:
         lines = fd.readlines()
-        a = lines.index('# Beginning of computer generated data:\n')
-        b = lines.index('# End of computer generated data\n')
-    lines[a + 1:b] = [txt]
-    with open(filename + '.new', 'w') as fd:
-        print(''.join(lines), end='', file=fd)
-    os.rename(filename + '.new', filename)
-    os.chmod(filename, 0o775)
+
+    a = lines.index('# Beginning of computer generated data:\n')
+    b = lines.index('# End of computer generated data\n')
+
+    if test:
+        if ''.join(lines[a + 1:b]) != txt:
+            raise ValueError(
+                'Please update ase/cli/complete.py using '
+                '"python3 -m ase.cli.completion".')
+    else:
+        lines[a + 1:b] = [txt]
+        new = path.with_name('complete.py.new')
+        with new.open('w') as fd:
+            print(''.join(lines), end='', file=fd)
+        new.rename(path)
+        path.chmod(0o775)
 
 
 if __name__ == '__main__':
     from ase.cli.main import commands
-    update(filename, commands)
+    update(path, commands)
