@@ -12,7 +12,7 @@ import ase.io.jsonio
 import json
 
 
-class Connection(object):
+class Connection:
     """
     Wrapper for the MySQL connection
 
@@ -49,8 +49,11 @@ class Connection(object):
     def close(self):
         self.con.close()
 
+    def rollback(self):
+        self.con.rollback()
 
-class MySQLCursor(object):
+
+class MySQLCursor:
     """
     Wrapper for the MySQL cursor. The most important task performed by this
     class is to translate SQLite queries to MySQL. Translation is needed
