@@ -1,6 +1,6 @@
 from ase.cell import Cell
 from ase.geometry.cell import (cell_to_cellpar, cellpar_to_cell,
-                               crystal_structure_from_cell, complete_cell,
+                               complete_cell,
                                is_orthorhombic, orthorhombic,)
 from ase.geometry.geometry import (wrap_positions,
                                    get_layers, find_mic,
@@ -17,8 +17,7 @@ from ase.geometry.minkowski_reduction import (minkowski_reduce,
 __all__ = ['Cell', 'wrap_positions', 'complete_cell',
            'is_orthorhombic', 'orthorhombic',
            'get_layers', 'find_mic', 'get_duplicate_atoms',
-           'cell_to_cellpar', 'cellpar_to_cell',
-           'crystal_structure_from_cell', 'distance',
+           'cell_to_cellpar', 'cellpar_to_cell', 'distance',
            'get_angles', 'get_distances', 'get_dihedrals',
            'get_angles_derivatives', 'get_distances_derivatives',
            'get_dihedrals_derivatives', 'conditional_find_mic',
