@@ -5,13 +5,11 @@ from ase.gui.i18n import _
 class Constraints:
     def __init__(self, gui):
         win = ui.Window(_('Constraints'))
-        win.add([ui.Button(_('Constrain'), self.selected),
+        win.add([ui.Button(_('Fix'), self.selected),
                  _('selected atoms')])
-        win.add([ui.Button(_('Constrain'), self.immobile),
-                 _('immobile atoms')])
-        win.add([ui.Button(_('Unconstrain'), self.unconstrain),
+        win.add([ui.Button(_('Release'), self.unconstrain),
                  _('selected atoms')])
-        win.add(ui.Button(_('Clear constraints'), self.clear))
+        win.add(ui.Button(_('Clear all constraints'), self.clear))
         self.gui = gui
 
     def selected(self):
@@ -22,11 +20,6 @@ class Constraints:
         self.gui.images.set_dynamic(self.gui.images.selected, True)
         self.gui.draw()
 
-    def immobile(self):
-        # XXX not working.
-        # Should constrain atoms that are not moving
-        self.gui.draw()
-
     def clear(self):
         # This clears *all* constraints.  But when we constrain, we
         # only add FixAtoms....
