@@ -70,7 +70,7 @@ class Images:
         else:
             return F
 
-    def initialize(self, images, filenames=None, init_magmom=False):
+    def initialize(self, images, filenames=None):
         nimages = len(images)
         if filenames is None:
             filenames = [None] * nimages
@@ -126,7 +126,6 @@ class Images:
         self.selected = np.zeros(self.maxnatoms, bool)
         self.selected_ordered = []
         self.visible = np.ones(self.maxnatoms, bool)
-        self.nselected = 0
         self.repeat = np.ones(3, int)
 
     def get_radii(self, atoms):
@@ -135,8 +134,7 @@ class Images:
         return radii
 
     def read(self, filenames, default_index=':', filetype=None):
-        from ase.utils import basestring
-        if isinstance(default_index, basestring):
+        if isinstance(default_index, str):
             default_index = string2index(default_index)
 
         images = []
@@ -198,7 +196,7 @@ class Images:
                     quantity = get_quantity()
             except Exception as err:
                 quantity = None
-                errmsg = ('An error occured while retrieving {} '
+                errmsg = ('An error occurred while retrieving {} '
                           'from the calculator: {}'.format(name, err))
                 warnings.warn(errmsg)
             return quantity
@@ -422,82 +420,10 @@ class Images:
             atoms = atoms[self.visible]
             if F is not None:
                 F = F[self.visible]
-        atoms.set_calculator(SinglePointCalculator(atoms,
-                                                   energy=E,
-                                                   forces=F))
+        atoms.calc = SinglePointCalculator(atoms, energy=E, forces=F)
         return atoms
 
     def delete(self, i):
         self.images.pop(i)
         self.filenames.pop(i)
         self.initialize(self.images, self.filenames)
-
-    def aneb(self):
-        raise NotImplementedError('broken at the moment')
-        n = self.nimages
-        assert n % 5 == 0
-        levels = n // 5
-        n = self.nimages = 2 * levels + 3
-        P = np.empty((self.nimages, self.natoms, 3))
-        V = np.empty((self.nimages, self.natoms, 3))
-        F = np.empty((self.nimages, self.natoms, 3))
-        E = np.empty(self.nimages)
-        for L in range(levels):
-            P[L] = self.P[L * 5]
-            P[n - L - 1] = self.P[L * 5 + 4]
-            V[L] = self.V[L * 5]
-            V[n - L - 1] = self.V[L * 5 + 4]
-            F[L] = self.F[L * 5]
-            F[n - L - 1] = self.F[L * 5 + 4]
-            E[L] = self.E[L * 5]
-            E[n - L - 1] = self.E[L * 5 + 4]
-        for i in range(3):
-            P[levels + i] = self.P[levels * 5 - 4 + i]
-            V[levels + i] = self.V[levels * 5 - 4 + i]
-            F[levels + i] = self.F[levels * 5 - 4 + i]
-            E[levels + i] = self.E[levels * 5 - 4 + i]
-        self.P = P
-        self.V = V
-        self.F = F
-        self.E = E
-
-    def interpolate(self, m):
-        raise NotImplementedError('broken at the moment')
-        assert self.nimages == 2
-        self.nimages = 2 + m
-        P = np.empty((self.nimages, self.natoms, 3))
-        V = np.empty((self.nimages, self.natoms, 3))
-        F = np.empty((self.nimages, self.natoms, 3))
-        A = np.empty((self.nimages, 3, 3))
-        E = np.empty(self.nimages)
-        T = np.empty((self.nimages, self.natoms), int)
-        D = np.empty((self.nimages, 3))
-        P[0] = self.P[0]
-        V[0] = self.V[0]
-        F[0] = self.F[0]
-        A[0] = self.A[0]
-        E[0] = self.E[0]
-        T[:] = self.T[0]
-        for i in range(1, m + 1):
-            x = i / (m + 1.0)
-            y = 1 - x
-            P[i] = y * self.P[0] + x * self.P[1]
-            V[i] = y * self.V[0] + x * self.V[1]
-            F[i] = y * self.F[0] + x * self.F[1]
-            A[i] = y * self.A[0] + x * self.A[1]
-            E[i] = y * self.E[0] + x * self.E[1]
-            D[i] = y * self.D[0] + x * self.D[1]
-        P[-1] = self.P[1]
-        V[-1] = self.V[1]
-        F[-1] = self.F[1]
-        A[-1] = self.A[1]
-        E[-1] = self.E[1]
-        D[-1] = self.D[1]
-        self.P = P
-        self.V = V
-        self.F = F
-        self.A = A
-        self.E = E
-        self.T = T
-        self.D = D
-        self.filenames[1:1] = [None] * m
