@@ -1,5 +1,3 @@
-import numpy as np
-
 import ase.gui.ui as ui
 from ase.gui.i18n import _
 
@@ -29,11 +27,3 @@ class Repeat:
         for r in self.repeat:
             r.value = 1
         self.gui.set_frame()
-
-    def set_unit_cell0(self):
-        self.gui.images.A *= self.gui.images.repeat.reshape((3, 1))
-        self.gui.images.E *= self.gui.images.repeat.prod()
-        self.gui.images.repeat = np.ones(3, int)
-        for r in self.repeat:
-            r.value = 1
-        self.gui.set_frame()
