@@ -18,14 +18,14 @@ def parse_geometry(filename):
     retval["Atomic_numbers"]: list of atomic numbers
     retval["Positions"]: list of [x, y, z] coordinates for each atoms.
     '''
-    with open(filename, 'r') as f:
-        lines = f.readlines()
+    with open(filename, 'r') as fd:
+        lines = fd.readlines()
         start_line = 0
         end_line = 0
         for i, line in enumerate(lines):
             if line == '====================  Atoms  =====================\n':
                 start_line = i
-            if start_line > 20 and len(line.split('=')) > 3:
+            if start_line != 0 and len(line.split('=')) > 3:
                 end_line = i
                 if not start_line == end_line:
                     break
@@ -68,8 +68,8 @@ def read_acemolecule_out(filename):
     excitation_energy = None
 #    results = {}
 #    if len(results)<1:
-    with open(filename, 'r') as f:
-        lines = f.readlines()
+    with open(filename, 'r') as fd:
+        lines = fd.readlines()
 
     for i in range(len(lines) - 1, 1, -1):
         line = lines[i].split()
@@ -116,20 +116,10 @@ def read_acemolecule_input(filename):
     =======
     ASE atoms object containing geometry only.
     '''
-    with open(filename, 'r') as f:
-        for line in f:
+    with open(filename, 'r') as fd:
+        for line in fd:
             if len(line.split('GeometryFilename')) > 1:
                 geometryfile = line.split()[1]
                 break
     atoms = read(geometryfile, format='xyz')
     return atoms
-
-
-if __name__ == "__main__":
-    import sys
-    from ase.io import read as ACE_read
-    label = str(sys.argv[1].split('.inp')[0])
-    system_changes = None
-    a = ACE_read(label + '.inp', format='acemolecule-input')
-
-    filename = label + '.log'
