@@ -226,7 +226,7 @@ def read_single_image(f, levcfg, imcon, natoms, is_trajectory, symbols=None):
     return atoms
 
 
-def write_dlp4(f, atoms, levcfg=0, title='CONFIG generated by ASE'):
+def write_dlp4(fd, atoms, levcfg=0, title='CONFIG generated by ASE'):
     """Write a DL_POLY_4 config file.
 
     Typically used indirectly through write('filename', atoms, format='dlp4').
@@ -234,7 +234,7 @@ def write_dlp4(f, atoms, levcfg=0, title='CONFIG generated by ASE'):
     Can be unforgiven with custom chemical element names.
     Please complain to alin@elena.space in case of bugs"""
 
-    f.write('{0:72s}\n'.format(title))
+    fd.write('{0:72s}\n'.format(title))
     natoms = len(atoms)
     npbc = sum(atoms.pbc)
     if npbc == 0:
@@ -248,11 +248,11 @@ def write_dlp4(f, atoms, levcfg=0, title='CONFIG generated by ASE'):
                          'Supported pbc are 000, 110, and 000.'
                          .format(atoms.pbc))
 
-    f.write('{0:10d}{1:10d}{2:10d}\n'.format(levcfg, imcon, natoms))
+    fd.write('{0:10d}{1:10d}{2:10d}\n'.format(levcfg, imcon, natoms))
     if imcon > 0:
         cell = atoms.get_cell()
         for j in range(3):
-            f.write('{0:20.10f}{1:20.10f}{2:20.10f}\n'.format(
+            fd.write('{0:20.10f}{1:20.10f}{2:20.10f}\n'.format(
                 cell[j, 0], cell[j, 1], cell[j, 2]))
     vels = []
     forces = []
@@ -267,19 +267,19 @@ def write_dlp4(f, atoms, levcfg=0, title='CONFIG generated by ASE'):
         sym = a.symbol
         if labels is not None:
             sym += labels[i]
-        f.write("{0:8s}{1:10d}\n{2:20.10f}{3:20.10f}{4:20.10f}\n".format(
+        fd.write("{0:8s}{1:10d}\n{2:20.10f}{3:20.10f}{4:20.10f}\n".format(
             sym, a.index + 1, a.x, a.y, a.z))
         if levcfg > 0:
             if vels is None:
-                f.write("{0:20.10f}{1:20.10f}{2:20.10f}\n".format(
+                fd.write("{0:20.10f}{1:20.10f}{2:20.10f}\n".format(
                     0.0, 0.0, 0.0))
             else:
-                f.write("{0:20.10f}{1:20.10f}{2:20.10f}\n".format(
+                fd.write("{0:20.10f}{1:20.10f}{2:20.10f}\n".format(
                     vels[a.index, 0], vels[a.index, 1], vels[a.index, 2]))
         if levcfg > 1:
             if forces is None:
-                f.write("{0:20.10f}{1:20.10f}{2:20.10f}\n".format(
+                fd.write("{0:20.10f}{1:20.10f}{2:20.10f}\n".format(
                     0.0, 0.0, 0.0))
             else:
-                f.write("{0:20.10f}{1:20.10f}{2:20.10f}\n".format(
+                fd.write("{0:20.10f}{1:20.10f}{2:20.10f}\n".format(
                     forces[a.index, 0], forces[a.index, 1], forces[a.index, 2]))
