@@ -8,6 +8,7 @@ import numpy as np
 import xml.etree.ElementTree as ET
 from ase.atoms import Atoms
 from ase.units import Bohr
+from ase.utils import writer
 from xml.dom import minidom
 
 
@@ -71,7 +72,8 @@ def read_exciting(fileobj, index=-1):
     return atoms
 
 
-def write_exciting(filename, images):
+@writer
+def write_exciting(fileobj, images):
     """writes exciting input structure in XML
 
     Parameters
@@ -84,12 +86,11 @@ def write_exciting(filename, images):
     Returns
     -------
     """
-    fileobj = open(filename, 'wb')
     root = atoms2etree(images)
     rough_string = ET.tostring(root, 'utf-8')
     reparsed = minidom.parseString(rough_string)
     pretty = reparsed.toprettyxml(indent="\t")
-    fileobj.write(pretty.encode('utf-8'))
+    fileobj.write(pretty)
 
 
 def atoms2etree(images):
