@@ -46,7 +46,9 @@ def read_turbomole(fd):
                     myconstraints.append(False)
             else:
                 myconstraints.append(False)
-
+    
+    # convert Turbomole ghost atom Q to X
+    atom_symbols = [element if element != 'Q' else 'X' for element in atom_symbols]
     atoms = Atoms(positions=atoms_pos, symbols=atom_symbols, pbc=False)
     c = FixAtoms(mask=myconstraints)
     atoms.set_constraint(c)
@@ -113,6 +115,9 @@ def read_turbomole_gradient(fd, index=-1):
                 # 0.00000000000000      0.00000000000000      0.00000000000000      c  # noqa: E501
                 try:
                     symbol = fields[3].lower().capitalize()
+                    # if dummy atom specified, substitute 'Q' with 'X'
+                    if symbol == 'Q':
+                        symbol = 'X'
                     position = tuple([Bohr * float(x) for x in fields[0:3]])
                 except ValueError as e:
                     raise TurbomoleFormatError() from e
@@ -151,6 +156,9 @@ def write_turbomole(fd, atoms):
 
     coord = atoms.get_positions()
     symbols = atoms.get_chemical_symbols()
+    
+    # convert X to Q for Turbomole ghost atoms
+    symbols = [element if element != 'X' else 'Q' for element in symbols]
 
     fix_indices = set()
     if atoms.constraints:
