@@ -167,7 +167,7 @@ def make_patch_list(writer):
         if a < writer.natoms:
             r = writer.d[a] / 2
             if writer.frac_occ:
-                site_occ = writer.occs[writer.tags[a]]
+                site_occ = writer.occs[str(writer.tags[a])]
                 # first an empty circle if a site is not fully occupied
                 if (np.sum([v for v in site_occ.values()])) < 1.0:
                     # fill with white
