@@ -2,7 +2,8 @@
 Module for parsing OUTCAR files.
 """
 from abc import ABC, abstractmethod
-from typing import Dict, Any, Sequence, TextIO, Iterator, Optional, Union
+from typing import (Dict, Any, Sequence, TextIO, Iterator, Optional, Union,
+                    List)
 import re
 from warnings import warn
 from pathlib import Path, PurePath
@@ -10,6 +11,7 @@ from pathlib import Path, PurePath
 import numpy as np
 import ase
 from ase import Atoms
+from ase.data import atomic_numbers
 from ase.io import ParseError, read
 from ase.io.utils import ImageChunk
 from ase.calculators.singlepoint import SinglePointDFTCalculator, SinglePointKPoint
@@ -79,7 +81,7 @@ class VaspPropertyParser(ABC):
     def parse(self, cursor: _CURSOR, lines: _CHUNK) -> _RESULT:
         """Extract a property from the cursor position.
         Assumes that "has_property" would evaluate to True
-        from cursor position"""
+        from cursor position """
 
 
 class SimpleProperty(VaspPropertyParser, ABC):
@@ -149,14 +151,77 @@ class SpeciesTypes(SimpleVaspHeaderParser):
     """Parse species types.
 
     Example line:
-    "POSCAR: Mg Al"
+    " POTCAR:    PAW_PBE Ni 02Aug2007"
+
+    We must parse this multiple times, as it's scattered in the header.
+    So this class has to simply parse the entire header.
     """
-    LINE_DELIMITER = 'POSCAR:'
+    LINE_DELIMITER = 'POTCAR:'
+
+    def __init__(self, *args, **kwargs):
+        self._species = []  # Store species as we find them
+        # We count the number of times we found the line,
+        # as we only want to parse every second,
+        # due to repeated entries in the OUTCAR
+        super().__init__(*args, **kwargs)
+
+    @property
+    def species(self) -> List[str]:
+        """Internal storage of each found line.
+        Will contain the double counting.
+        Use the get_species() method to get the un-doubled list."""
+        return self._species
+
+    def get_species(self) -> List[str]:
+        """The OUTCAR will contain two 'POTCAR:' entries per species.
+        This method only returns the first half,
+        effectively removing the double counting.
+        """
+        # Get the index of the first half
+        # In case we have an odd number, we round up (for testing purposes)
+        # Tests like to just add species 1-by-1
+        # Having an odd number should never happen in a real OUTCAR
+        # For even length lists, this is just equivalent to idx = len(self.species) // 2
+        idx = sum(divmod(len(self.species), 2))
+        # Make a copy
+        return list(self.species[:idx])
+
+    def _make_returnval(self) -> _RESULT:
+        """Construct the return value for the "parse" method"""
+        return {'species': self.get_species()}
 
     def parse(self, cursor: _CURSOR, lines: _CHUNK) -> _RESULT:
         line = lines[cursor].strip()
-        species = line.split()[1:]
-        return {'species': species}
+
+        parts = line.split()
+        # Determine in what position we'd expect to find the symbol
+        if '1/r potential' in line:
+            # This denotes an AE potential
+            # Currently only H_AE
+            # "  H  1/r potential  "
+            idx = 1
+        else:
+            # Regular PAW potential, e.g.
+            # "PAW_PBE H1.25 07Sep2000" or
+            # "PAW_PBE Fe_pv 02Aug2007"
+            idx = 2
+
+        sym = parts[idx]
+        # remove "_h", "_GW", "_3" tags etc.
+        sym = sym.split('_')[0]
+        # in the case of the "H1.25" potentials etc.,
+        # remove any non-alphabetic characters
+        sym = ''.join([s for s in sym if s.isalpha()])
+
+        if sym not in atomic_numbers:
+            # Check that we have properly parsed the symbol, and we found
+            # an element
+            raise ParseError(
+                f'Found an unexpected symbol {sym} in line {line}')
+
+        self.species.append(sym)
+
+        return self._make_returnval()
 
 
 class IonsPerSpecies(SimpleVaspHeaderParser):
@@ -401,16 +466,23 @@ class Kpoints(VaspChunkPropertyParser):
 
 class DefaultParsersContainer:
     """Container for the default OUTCAR parsers.
-    Allows for modification of the global default parsers."""
-    def __init__(self, parsers_cls):
-        self.parsers_dct = {
-            parser.get_name(): parser
-            for parser in parsers_cls
-        }
+    Allows for modification of the global default parsers.
+    
+    Takes in an arbitrary number of parsers. The parsers should be uninitialized,
+    as they are created on request.
+    """
+    def __init__(self, *parsers_cls):
+        self._parsers_dct = {}
+        for parser in parsers_cls:
+            self.add_parser(parser)
 
     @property
-    def parsers(self):
-        """Return a copy of the internally stored parsers"""
+    def parsers_dct(self) -> dict:
+        return self._parsers_dct
+
+    def make_parsers(self):
+        """Return a copy of the internally stored parsers.
+        Parsers are created upon request."""
         return list(parser() for parser in self.parsers_dct.values())
 
     def remove_parser(self, name: str):
@@ -423,7 +495,8 @@ class DefaultParsersContainer:
 
 
 class TypeParser(ABC):
-    """Base class for parsing a type, e.g. header or chunk, by applying the internal attached parsers"""
+    """Base class for parsing a type, e.g. header or chunk, 
+    by applying the internal attached parsers"""
     def __init__(self, parsers):
         self.parsers = parsers
 
@@ -432,7 +505,7 @@ class TypeParser(ABC):
         return self._parsers
 
     @parsers.setter
-    def parsers(self, new_parsers):
+    def parsers(self, new_parsers) -> None:
         self._check_parsers(new_parsers)
         self._parsers = new_parsers
 
@@ -440,7 +513,7 @@ class TypeParser(ABC):
     def _check_parsers(self, parsers) -> None:
         """Check the parsers are of correct type"""
 
-    def parse(self, lines):
+    def parse(self, lines) -> _RESULT:
         """Execute the attached paresers, and return the parsed properties"""
         properties = {}
         for cursor, _ in enumerate(lines):
@@ -466,11 +539,11 @@ class ChunkParser(TypeParser, ABC):
         return self._header
 
     @header.setter
-    def header(self, value: Optional[_HEADER]):
+    def header(self, value: Optional[_HEADER]) -> None:
         self._header = value or {}
         self.update_parser_headers()
 
-    def update_parser_headers(self):
+    def update_parser_headers(self) -> None:
         """Apply the header to all available parsers"""
         for parser in self.parsers:
             parser.header = self.header
@@ -510,7 +583,7 @@ class OutcarChunkParser(ChunkParser):
                  header: _HEADER = None,
                  parsers: Sequence[VaspChunkPropertyParser] = None):
         global default_chunk_parsers
-        parsers = parsers or default_chunk_parsers.parsers
+        parsers = parsers or default_chunk_parsers.make_parsers()
         super().__init__(parsers, header=header)
 
     def build(self, lines: _CHUNK) -> Atoms:
@@ -521,7 +594,7 @@ class OutcarChunkParser(ChunkParser):
         symbols = self.header['symbols']
         constraint = self.header.get('constraint', None)
 
-        atoms_kwargs = dict(symbols=symbols, constraint=constraint)
+        atoms_kwargs = dict(symbols=symbols, constraint=constraint, pbc=True)
 
         # Find some required properties in the parsed results.
         # Raise ParseError if they are not present
@@ -549,7 +622,7 @@ class OutcarHeaderParser(HeaderParser):
                  parsers: Sequence[VaspHeaderPropertyParser] = None,
                  workdir: Union[str, PurePath] = None):
         global default_header_parsers
-        parsers = parsers or default_header_parsers.parsers
+        parsers = parsers or default_header_parsers.make_parsers()
         super().__init__(parsers)
         self.workdir = workdir
 
@@ -691,7 +764,7 @@ def outcarchunks(fd: TextIO,
 
 
 # Create the default chunk parsers
-default_chunk_parsers = DefaultParsersContainer([
+default_chunk_parsers = DefaultParsersContainer(
     Cell,
     PositionsAndForces,
     Stress,
@@ -700,12 +773,12 @@ default_chunk_parsers = DefaultParsersContainer([
     EFermi,
     Kpoints,
     Energy,
-])
+)
 
 # Create the default header parsers
-default_header_parsers = DefaultParsersContainer([
+default_header_parsers = DefaultParsersContainer(
     SpeciesTypes,
     IonsPerSpecies,
     Spinpol,
     KpointHeader,
-])
+)
