@@ -2,18 +2,13 @@ import numpy as np
 
 from ase.atoms import Atoms
 from ase.units import Hartree
-from ase.parallel import paropen
 from ase.data import atomic_numbers
 from ase.calculators.singlepoint import SinglePointCalculator
+from ase.utils import writer, reader
 
 
+@writer
 def write_xsf(fileobj, images, data=None):
-    if isinstance(fileobj, str):
-        fileobj = paropen(fileobj, 'w')
-
-    if hasattr(images, 'get_positions'):
-        images = [images]
-
     is_anim = len(images) > 1
 
     if is_anim:
@@ -119,6 +114,7 @@ def write_xsf(fileobj, images, data=None):
     fileobj.write('END_BLOCK_DATAGRID_3D\n')
 
 
+@reader
 def iread_xsf(fileobj, read_data=False):
     """Yield images and optionally data from xsf file.
 
@@ -127,9 +123,6 @@ def iread_xsf(fileobj, read_data=False):
     Images are Atoms objects and data is a numpy array.
 
     Presently supports only a single 3D datagrid."""
-    if isinstance(fileobj, str):
-        fileobj = open(fileobj)
-
     def _line_generator_func():
         for line in fileobj:
             line = line.strip()
