@@ -2,17 +2,25 @@ import sys
 import threading
 import warnings
 from abc import ABC, abstractmethod
+import time
 
 import numpy as np
 
+from scipy.interpolate import CubicSpline
+from scipy.integrate import cumtrapz
+
 import ase.parallel
 from ase.build import minimize_rotation_and_translation
 from ase.calculators.calculator import Calculator
 from ase.calculators.singlepoint import SinglePointCalculator
-from ase.geometry import find_mic
 from ase.optimize import MDMin
+from ase.optimize.optimize import Optimizer
+from ase.optimize.sciopt import OptimizerConvergenceError
+from ase.geometry import find_mic
 from ase.utils import lazyproperty, deprecated
 from ase.utils.forcecurve import fit_images
+from ase.optimize.precon import Precon, PreconImages
+from ase.optimize.ode import ode12r
 
 
 class Spring:
@@ -66,6 +74,14 @@ class NEBState:
         beelinelength = np.linalg.norm(beeline)
         return beelinelength / (self.neb.nimages - 1)
 
+    @lazyproperty
+    def nimages(self):
+        return len(self.images)
+    
+    @property
+    def precon(self):
+        return self.neb.precon
+
 
 class NEBMethod(ABC):
     def __init__(self, neb):
@@ -80,11 +96,16 @@ class NEBMethod(ABC):
                         spring1, spring2, i):
         ...
 
+    def adjust_positions(self, positions):
+        return positions
 
-class ImprovedTangent(NEBMethod):
-    """Tangent estimates are improved according to Eqs. 8-11 in paper I.
-       Tangents are weighted at extrema to ensure smooth transitions between
-       the positive and negative tangents."""
+
+class ImprovedTangentMethod(NEBMethod):
+    """
+    Tangent estimates are improved according to Eqs. 8-11 in paper I.
+    Tangents are weighted at extrema to ensure smooth transitions between
+    the positive and negative tangents.
+    """
 
     def get_tangent(self, state, spring1, spring2, i):
         energies = state.energies
@@ -112,10 +133,12 @@ class ImprovedTangent(NEBMethod):
         imgforce += (spring2.nt * spring2.k - spring1.nt * spring1.k) * tangent
 
 
-class ASENEB(NEBMethod):
-    """Standard NEB implementation in ASE. The tangent of each image is
-       estimated from the spring closest to the saddle point in each
-       spring pair."""
+class ASENEBMethod(NEBMethod):
+    """
+    Standard NEB implementation in ASE. The tangent of each image is
+    estimated from the spring closest to the saddle point in each
+    spring pair.
+    """
 
     def get_tangent(self, state, spring1, spring2, i):
         imax = self.neb.imax
@@ -137,9 +160,11 @@ class ASENEB(NEBMethod):
             spring2.t * spring2.k, tangent) * factor
 
 
-class EB(NEBMethod):
-    """Elastic band method. The full spring force is included."""
-
+class FullSpringMethod(NEBMethod):
+    """
+    Elastic band method. The full spring force is included.
+    """
+    
     def get_tangent(self, state, spring1, spring2, i):
         # Tangents are bisections of spring-directions
         # (formula C8 of paper III)
@@ -166,13 +191,64 @@ class EB(NEBMethod):
             imgforce += f1 + f2
 
 
+class BaseSplineMethod(NEBMethod):
+    """
+    Base class for SplineNEB and String methods
+
+    Can optionally be preconditioned, as described in the following article:
+
+        S. Makri, C. Ortner and J. R. Kermode, J. Chem. Phys.
+        150, 094109 (2019)
+        https://dx.doi.org/10.1063/1.5064465
+    """
+    def __init__(self, neb):
+        NEBMethod.__init__(self, neb)
+
+    def get_tangent(self, state, spring1, spring2, i):
+        return state.precon.get_tangent(i)
+
+    def add_image_force(self, state, tangential_force, tangent, imgforce,
+                        spring1, spring2, i):
+        # project out tangential component (Eqs 6 and 7 in Paper IV)
+        imgforce -= tangential_force * tangent
+
+
+class SplineMethod(BaseSplineMethod):
+    """
+    NEB using spline interpolation, plus optional preconditioning
+    """
+    def add_image_force(self, state, tangential_force, tangent, imgforce,
+                        spring1, spring2, i):
+        super().add_image_force(state, tangential_force,
+                                tangent, imgforce, spring1, spring2, i)
+        eta = state.precon.get_spring_force(i, spring1.k, spring2.k, tangent)
+        imgforce += eta
+
+
+class StringMethod(BaseSplineMethod):
+    """
+    String method using spline interpolation, plus optional preconditioning
+    """
+    def adjust_positions(self, positions):
+        # fit cubic spline to positions, reinterpolate to equispace images
+        # note this uses the preconditioned distance metric.
+        fit = self.neb.spline_fit(positions)
+        new_s = np.linspace(0.0, 1.0, self.neb.nimages)
+        new_positions = fit.x(new_s[1:-1]).reshape(-1, 3)
+        return new_positions
+
+
 def get_neb_method(neb, method):
     if method == 'eb':
-        return EB(neb)
+        return FullSpringMethod(neb)
     elif method == 'aseneb':
-        return ASENEB(neb)
+        return ASENEBMethod(neb)
     elif method == 'improvedtangent':
-        return ImprovedTangent(neb)
+        return ImprovedTangentMethod(neb)
+    elif method == 'spline':
+        return SplineMethod(neb)
+    elif method == 'string':
+        return StringMethod(neb)
     else:
         raise ValueError(f'Bad method: {method}')
 
@@ -180,7 +256,8 @@ def get_neb_method(neb, method):
 class BaseNEB:
     def __init__(self, images, k=0.1, climb=False, parallel=False,
                  remove_rotation_and_translation=False, world=None,
-                 method='aseneb', allow_shared_calculator=False):
+                 method='aseneb', allow_shared_calculator=False, precon=None):
+        
         self.images = images
         self.climb = climb
         self.parallel = parallel
@@ -202,9 +279,16 @@ class BaseNEB:
 
         self.remove_rotation_and_translation = remove_rotation_and_translation
 
-        self.method = method
-        self.neb_method = get_neb_method(self, method)
+        if method in ['aseneb', 'eb', 'improvedtangent', 'spline', 'string']:
+            self.method = method
+        else:
+            raise NotImplementedError(method)
 
+        if precon is not None and method not in ['spline', 'string']:
+            raise NotImplementedError(f'no precon implemented: {method}')
+        self.precon = precon
+
+        self.neb_method = get_neb_method(self, method)
         if isinstance(k, (float, int)):
             k = [k] * (self.nimages - 1)
         self.k = list(k)
@@ -214,13 +298,12 @@ class BaseNEB:
         self.world = world
 
         if parallel:
-            assert world.size == 1 or world.size % (self.nimages - 2) == 0
             if self.allow_shared_calculator:
                 raise RuntimeError(
                     "Cannot use shared calculators in parallel in NEB.")
-
         self.real_forces = None  # ndarray of shape (nimages, natom, 3)
         self.energies = None  # ndarray of shape (nimages,)
+        self.residuals = None  # ndarray of shape (nimages,)
 
     @property
     def natoms(self):
@@ -235,7 +318,7 @@ class BaseNEB:
                                 **results_to_include):
         atoms.calc = SinglePointCalculator(atoms=atoms, **results_to_include)
 
-    def interpolate(self, method='linear', mic=False):
+    def interpolate(self, method='linear', mic=False, apply_constraint=None):
         """Interpolate the positions of the interior images between the
         initial state (image 0) and final state (image -1).
 
@@ -245,11 +328,20 @@ class BaseNEB:
             idpp uses an image-dependent pair potential.
         mic: bool
             Use the minimum-image convention when interpolating.
+        apply_constraint: bool
+            Controls if the constraints attached to the images
+            are ignored or applied when setting the interpolated positions.
+            Default value is None, in this case the resulting constrained
+            positions (apply_constraint=True) are compared with unconstrained
+            positions (apply_constraint=False),
+            if the positions are not the same
+            the user is required to specify the desired behaviour
+            by setting up apply_constraint keyword argument to False or True.
         """
         if self.remove_rotation_and_translation:
             minimize_rotation_and_translation(self.images[0], self.images[-1])
 
-        interpolate(self.images, mic)
+        interpolate(self.images, mic, apply_constraint=apply_constraint)
 
         if method == 'idpp':
             idpp_interpolate(images=self, traj=None, log=None, mic=mic)
@@ -270,7 +362,11 @@ class BaseNEB:
             n1 = n2
         return positions
 
-    def set_positions(self, positions):
+    def set_positions(self, positions, adjust_positions=True):
+        if adjust_positions:
+            # optional reparameterisation step: some NEB methods need to adjust
+            # positions e.g. string method does this to equispace the images)
+            positions = self.neb_method.adjust_positions(positions)
         n1 = 0
         for image in self.images[1:-1]:
             n2 = n1 + self.natoms
@@ -308,6 +404,7 @@ class BaseNEB:
             for i in range(1, self.nimages - 1):
                 energies[i] = images[i].get_potential_energy()
                 forces[i - 1] = images[i].get_forces()
+
         elif self.world.size == 1:
             def run(image, energies, forces):
                 energies[:] = image.get_potential_energy()
@@ -341,12 +438,21 @@ class BaseNEB:
                 root = (i - 1) * self.world.size // (self.nimages - 2)
                 self.world.broadcast(energies[i:i + 1], root)
                 self.world.broadcast(forces[i - 1], root)
+                
+        # if this is the first force call, we need to build the preconditioners
+        if (self.precon is None or isinstance(self.precon, str) or
+            isinstance(self.precon, Precon)):
+            self.precon = PreconImages(self.precon, images)
+            
+        # apply preconditioners to transform forces
+        # for the default IdentityPrecon this does not change their values
+        precon_forces = self.precon.apply(forces, index=slice(1, -1))
 
         # Save for later use in iterimages:
         self.energies = energies
         self.real_forces = np.zeros((self.nimages, self.natoms, 3))
         self.real_forces[1:-1] = forces
-
+        
         state = NEBState(self, images, energies)
 
         # Can we get rid of self.energies, self.imax, self.emax etc.?
@@ -355,13 +461,16 @@ class BaseNEB:
 
         spring1 = state.spring(0)
 
+        self.residuals = []
         for i in range(1, self.nimages - 1):
             spring2 = state.spring(i)
             tangent = self.neb_method.get_tangent(state, spring1, spring2, i)
 
-            imgforce = forces[i - 1]
-            # Get overlap between PES-derived force and tangent
-            tangential_force = np.vdot(imgforce, tangent)
+            # Get overlap between full PES-derived force and tangent
+            tangential_force = np.vdot(forces[i - 1], tangent)
+            
+            # from now on we use the preconditioned forces (equal for precon=ID)
+            imgforce = precon_forces[i - 1]
 
             if i == self.imax and self.climb:
                 """The climbing image, imax, is not affected by the spring
@@ -377,9 +486,24 @@ class BaseNEB:
                 self.neb_method.add_image_force(state, tangential_force,
                                                 tangent, imgforce, spring1,
                                                 spring2, i)
+                # compute the residual - with ID precon, this is just max force
+                residual = self.precon.get_residual(i, imgforce)
+                self.residuals.append(residual)
 
             spring1 = spring2
-        return forces.reshape((-1, 3))
+                    
+        return precon_forces.reshape((-1, 3))
+
+    def get_residual(self):
+        """Return residual force along the band.
+
+        Typically this the maximum force component on any image. For
+        non-trivial preconditioners, the appropriate preconditioned norm
+        is used to compute the residual.
+        """
+        if self.residuals is None:
+            raise RuntimeError("get_residual() called before get_forces()")
+        return np.max(self.residuals)
 
     def get_potential_energy(self, force_consistent=False):
         """Return the maximum potential energy along the band.
@@ -436,13 +560,60 @@ class BaseNEB:
                     forces=self.real_forces[i])
 
                 yield atoms
+                
+    def spline_fit(self, positions=None, norm='precon'):
+        """
+        Fit a cubic spline to this NEB
+
+        Args:
+            norm (str, optional): Norm to use: 'precon' (default) or 'euclidean'
+
+        Returns:
+            fit: ase.precon.precon.SplineFit instance
+        """
+        if norm == 'precon':
+            if self.precon is None or isinstance(self.precon, str):
+                self.precon = PreconImages(self.precon, self.images)
+            precon = self.precon
+            # if this is the first call, we need to build the preconditioners
+        elif norm == 'euclidean':
+            precon = PreconImages('ID', self.images)
+        else:
+            raise ValueError(f'unsupported norm {norm}')
+        return precon.spline_fit(positions)
+    
+    def integrate_forces(self, spline_points=1000, bc_type='not-a-knot'):
+        """Use spline fit to integrate forces along MEP to approximate
+        energy differences using the virtual work approach.
+
+        Args:
+            spline_points (int, optional): Number of points. Defaults to 1000.
+            bc_type (str, optional): Boundary conditions, default 'not-a-knot'.
+
+        Returns:
+            s: reaction coordinate in range [0, 1], with `spline_points` entries
+            E: result of integrating forces, on the same grid as `s`.
+            F: projected forces along MEP
+        """
+        # note we use standard Euclidean rather than preconditioned norm
+        # to compute the virtual work
+        fit = self.spline_fit(norm='euclidean')
+        forces = np.array([image.get_forces().reshape(-1)
+                           for image in self.images])
+        f = CubicSpline(fit.s, forces, bc_type=bc_type)
+
+        s = np.linspace(0.0, 1.0, spline_points, endpoint=True)
+        dE = f(s) * fit.dx_ds(s)
+        F = dE.sum(axis=1)
+        E = -cumtrapz(F, s, initial=0.0)
+        return s, E, F
 
 
 class DyNEB(BaseNEB):
     def __init__(self, images, k=0.1, fmax=0.05, climb=False, parallel=False,
                  remove_rotation_and_translation=False, world=None,
                  dynamic_relaxation=True, scale_fmax=0., method='aseneb',
-                 allow_shared_calculator=False):
+                 allow_shared_calculator=False, precon=None):
         """
         Subclass of NEB that allows for scaled and dynamic optimizations of
         images. This method, which only works in series, does not perform
@@ -473,7 +644,7 @@ class DyNEB(BaseNEB):
             images, k=k, climb=climb, parallel=parallel,
             remove_rotation_and_translation=remove_rotation_and_translation,
             world=world, method=method,
-            allow_shared_calculator=allow_shared_calculator)
+            allow_shared_calculator=allow_shared_calculator, precon=precon)
         self.fmax = fmax
         self.dynamic_relaxation = dynamic_relaxation
         self.scale_fmax = scale_fmax
@@ -554,7 +725,8 @@ def _check_deprecation(keyword, kwargs):
 class NEB(DyNEB):
     def __init__(self, images, k=0.1, climb=False, parallel=False,
                  remove_rotation_and_translation=False, world=None,
-                 method='aseneb', allow_shared_calculator=False, **kwargs):
+                 method='aseneb', allow_shared_calculator=False,
+                 precon=None, **kwargs):
         """Nudged elastic band.
 
         Paper I:
@@ -574,6 +746,12 @@ class NEB(DyNEB):
             145, 094107 (2016)
             https://doi.org/10.1063/1.4961868
 
+        Paper IV:
+
+            S. Makri, C. Ortner and J. R. Kermode, J. Chem. Phys.
+            150, 094109 (2019)
+            https://dx.doi.org/10.1063/1.5064465
+
         images: list of Atoms objects
             Images defining path from initial to final state.
         k: float or list of floats
@@ -587,15 +765,21 @@ class NEB(DyNEB):
             rotation during NEB. By default applied non-periodic
             systems
         method: string of method
-            Choice betweeen three method:
+            Choice betweeen five methods:
 
             * aseneb: standard ase NEB implementation
             * improvedtangent: Paper I NEB implementation
             * eb: Paper III full spring force implementation
+            * spline: Paper IV spline interpolation (supports precon)
+            * string: Paper IV string method (supports precon)
         allow_shared_calculator: bool
             Allow images to share the same calculator between them.
             Incompatible with parallelisation over images.
-
+        precon: string, :class:`ase.optimize.precon.Precon` instance or list of
+            instances. If present, enable preconditioing as in Paper IV. This is
+            possible using the 'spline' or 'string' methods only.
+            Default is no preconditioning (precon=None), which is converted to
+            a list of :class:`ase.precon.precon.IdentityPrecon` instances.
         """
         for keyword in 'dynamic_relaxation', 'fmax', 'scale_fmax':
             _check_deprecation(keyword, kwargs)
@@ -616,8 +800,122 @@ class NEB(DyNEB):
             remove_rotation_and_translation=remove_rotation_and_translation,
             world=world, method=method,
             allow_shared_calculator=allow_shared_calculator,
-            **defaults,
-        )
+            precon=precon,
+            **defaults)
+
+
+class NEBOptimizer(Optimizer):
+    """
+    This optimizer applies an adaptive ODE solver to a NEB
+
+    Details of the adaptive ODE solver are described in paper IV
+    """
+    def __init__(self,
+                 neb,
+                 restart=None, logfile='-', trajectory=None,
+                 master=None,
+                 append_trajectory=False,
+                 method='ODE',
+                 alpha=0.01,
+                 verbose=0,
+                 rtol=0.1,
+                 C1=1e-2,
+                 C2=2.0):
+
+        super().__init__(atoms=neb, restart=restart,
+                         logfile=logfile, trajectory=trajectory,
+                         master=master,
+                         append_trajectory=append_trajectory,
+                         force_consistent=False)
+        self.neb = neb
+
+        method = method.lower()
+        methods = ['ode', 'static', 'krylov']
+        if method not in methods:
+            raise ValueError(f'method must be one of {methods}')
+        self.method = method
+
+        self.alpha = alpha
+        self.verbose = verbose
+        self.rtol = rtol
+        self.C1 = C1
+        self.C2 = C2
+
+    def force_function(self, X):
+        positions = X.reshape((self.neb.nimages - 2) *
+                              self.neb.natoms, 3)
+        self.neb.set_positions(positions)
+        forces = self.neb.get_forces().reshape(-1)
+        return forces
+
+    def get_residual(self, F=None, X=None):
+        return self.neb.get_residual()
+
+    def log(self):
+        fmax = self.get_residual()
+        T = time.localtime()
+        if self.logfile is not None:
+            name = f'{self.__class__.__name__}[{self.method}]'
+            if self.nsteps == 0:
+                args = (" " * len(name), "Step", "Time", "fmax")
+                msg = "%s  %4s %8s %12s\n" % args
+                self.logfile.write(msg)
+
+            args = (name, self.nsteps, T[3], T[4], T[5], fmax)
+            msg = "%s:  %3d %02d:%02d:%02d %12.4f\n" % args
+            self.logfile.write(msg)
+            self.logfile.flush()
+
+    def callback(self, X, F=None):
+        self.log()
+        self.call_observers()
+        self.nsteps += 1
+    
+    def run_ode(self, fmax):
+        try:
+            ode12r(self.force_function,
+                   self.neb.get_positions().reshape(-1),
+                   fmax=fmax,
+                   rtol=self.rtol,
+                   C1=self.C1,
+                   C2=self.C2,
+                   steps=self.max_steps,
+                   verbose=self.verbose,
+                   callback=self.callback,
+                   residual=self.get_residual)
+            return True
+        except OptimizerConvergenceError:
+            return False
+               
+    def run_static(self, fmax):
+        X = self.neb.get_positions().reshape(-1)
+        for step in range(self.max_steps):
+            F = self.force_function(X)
+            if self.neb.get_residual() <= fmax:
+                return True
+            X += self.alpha * F
+            self.callback(X)
+        return False
+
+    def run(self, fmax=0.05, steps=None, method=None):
+        """
+        Optimize images to obtain the minimum energy path
+
+        Parameters
+        ----------
+        fmax - desired force tolerance
+        steps - maximum number of steps
+        """
+        if steps:
+            self.max_steps = steps
+        if method is None:
+            method = self.method
+        if method == 'ode':
+            return self.run_ode(fmax)
+        elif method == 'static':
+            return self.run_static(fmax)
+        else:
+            raise ValueError(f'unknown method: {self.method}')
 
 
 class IDPP(Calculator):
@@ -671,7 +969,7 @@ class SingleCalculatorNEB(NEB):
 
 
 def interpolate(images, mic=False, interpolate_cell=False,
-                use_scaled_coord=False):
+                use_scaled_coord=False, apply_constraint=None):
     """Given a list of images, linearly interpolate the positions of the
     interior images.
 
@@ -683,6 +981,14 @@ def interpolate(images, mic=False, interpolate_cell=False,
     use_scaled_coord: bool
          Use scaled/internal/fractional coordinates instead of real ones for the
          interpolation. Not implemented for NEB calculations!
+    apply_constraint: bool
+         Controls if the constraints attached to the images
+         are ignored or applied when setting the interpolated positions.
+         Default value is None, in this case the resulting constrained positions
+         (apply_constraint=True) are compared with unconstrained positions
+         (apply_constraint=False), if the positions are not the same
+         the user is required to specify the desired behaviour
+         by setting up apply_constraint keyword argument to False or True.
     """
     if use_scaled_coord:
         pos1 = images[0].get_scaled_positions(wrap=mic)
@@ -707,7 +1013,24 @@ def interpolate(images, mic=False, interpolate_cell=False,
         if use_scaled_coord:
             images[i].set_scaled_positions(new_pos)
         else:
-            images[i].set_positions(new_pos)
+            if apply_constraint is None:
+                unconstrained_image = images[i].copy()
+                unconstrained_image.set_positions(new_pos,
+                                                  apply_constraint=False)
+                images[i].set_positions(new_pos, apply_constraint=True)
+                try:
+                    np.testing.assert_allclose(unconstrained_image.positions,
+                                               images[i].positions)
+                except AssertionError:
+                    raise RuntimeError(f"Constraint(s) in image number {i} \n"
+                                       f"affect the interpolation results.\n"
+                                       "Please specify if you want to \n"
+                                       "apply or ignore the constraints \n"
+                                       "during the interpolation \n"
+                                       "with apply_constraint argument.")
+            else:
+                images[i].set_positions(new_pos,
+                                        apply_constraint=apply_constraint)
 
 
 def idpp_interpolate(images, traj='idpp.traj', log='idpp.log', fmax=0.1,
