@@ -8,9 +8,11 @@ from ase.optimize.bfgs import BFGS
 from ase.optimize.oldqn import GoodOldQuasiNewton
 from ase.optimize.gpmin.gpmin import GPMin
 from ase.optimize.berny import Berny
+from ase.optimize.ode import ODE12r
+from ase.optimize.optimize import RestartError
 QuasiNewton = BFGSLineSearch
 
 __all__ = ['MDMin', 'FIRE', 'LBFGS',
            'LBFGSLineSearch', 'BFGSLineSearch', 'BFGS',
            'GoodOldQuasiNewton', 'QuasiNewton', 'GPMin',
-           'Berny']
+           'Berny', 'ODE12r', 'RestartError']
