@@ -1,8 +1,6 @@
-# -*- coding: utf-8 -*-
 import numpy as np
 
 from ase.optimize.optimize import Optimizer
-from ase.utils import basestring
 from ase.utils.linesearch import LineSearch
 
 
@@ -38,7 +36,7 @@ class LBFGS(Optimizer):
         maxstep: float
             How far is a single atom allowed to move. This is useful for DFT
             calculations where wavefunctions can be reused if steps are small.
-            Default is 0.04 Angstrom.
+            Default is 0.2 Angstrom.
 
         memory: int
             Number of steps to be stored. Default value is 100. Three numpy
@@ -68,13 +66,14 @@ class LBFGS(Optimizer):
                            force_consistent=force_consistent)
 
         if maxstep is not None:
-            if maxstep > 1.0:
-                raise ValueError('You are using a much too large value for ' +
-                                 'the maximum step size: %.1f Angstrom' %
-                                 maxstep)
             self.maxstep = maxstep
         else:
-            self.maxstep = 0.04
+            self.maxstep = self.defaults['maxstep']
+
+        if self.maxstep > 1.0:
+            raise ValueError('You are using a much too large value for ' +
+                             'the maximum step size: %.1f Angstrom' %
+                             maxstep)
 
         self.memory = memory
         # Initial approximation of inverse Hessian 1./70. is to emulate the
@@ -91,7 +90,7 @@ class LBFGS(Optimizer):
         self.iteration = 0
         self.s = []
         self.y = []
-        # Store also rho, to avoid calculationg the dot product again and
+        # Store also rho, to avoid calculating the dot product again and
         # again.
         self.rho = []
 
@@ -195,7 +194,7 @@ class LBFGS(Optimizer):
 
     def replay_trajectory(self, traj):
         """Initialize history from old trajectory."""
-        if isinstance(traj, basestring):
+        if isinstance(traj, str):
             from ase.io.trajectory import Trajectory
             traj = Trajectory(traj, 'r')
         r0 = None
