@@ -15,7 +15,7 @@ mask = [atom.tag > 1 for atom in slab]
 slab.set_constraint(FixAtoms(mask=mask))
 
 # Use EMT potential:
-slab.set_calculator(EMT())
+slab.calc = EMT()
 
 # Initial state:
 qn = QuasiNewton(slab, logfile=None)
