@@ -4,8 +4,8 @@ Provides FixSymmetry class to preserve spacegroup symmetry during optimisation
 import warnings
 import numpy as np
 
-from ase.constraints import (FixConstraint, voigt_6_to_full_3x3_stress,
-                             full_3x3_to_voigt_6_stress)
+from ase.constraints import FixConstraint
+from ase.stress import voigt_6_to_full_3x3_stress, full_3x3_to_voigt_6_stress
 from ase.utils import atoms_to_spglib_cell
 
 
