@@ -1,7 +1,7 @@
 import collections
 from functools import reduce, singledispatch
 from typing import (Any, Dict, Iterable, List, Optional,
-                    overload, Sequence, Tuple, TypeVar, Union)
+                    overload, Sequence, TypeVar, Union)
 
 import numpy as np
 from ase.spectrum.dosdata import DOSData, RawDOSData, GridDOSData, Info
@@ -17,10 +17,10 @@ class DOSCollection(collections.abc.Sequence):
     def __init__(self, dos_series: Iterable[DOSData]) -> None:
         self._data = list(dos_series)
 
-    def sample(self,
-               energies: Sequence[float],
-               width: float = 0.1,
-               smearing: str = 'Gauss') -> np.ndarray:
+    def _sample(self,
+                energies: Sequence[float],
+                width: float = 0.1,
+                smearing: str = 'Gauss') -> np.ndarray:
         """Sample the DOS data at chosen points, with broadening
 
         This samples the underlying DOS data in the same way as the .sample()
@@ -40,9 +40,10 @@ class DOSCollection(collections.abc.Sequence):
 
         if len(self) == 0:
             raise IndexError("No data to sample")
-        return np.asarray([data.sample(energies,
-                                       width=width, smearing=smearing)
-                           for data in self])
+
+        return np.asarray(
+            [data._sample(energies, width=width, smearing=smearing)
+             for data in self])
 
     def plot(self,
              npts: int = 1000,
@@ -63,8 +64,8 @@ class DOSCollection(collections.abc.Sequence):
 
         Args:
             npts, xmin, xmax: output data range, as passed to self.sample_grid
-            width: Width of broadening kernel, passed to self.sample()
-            smearing: selection of broadening kernel, passed to self.sample()
+            width: Width of broadening kernel, passed to self.sample_grid()
+            smearing: selection of broadening kernel for self.sample_grid()
             ax: existing Matplotlib axes object. If not provided, a new figure
                 with one set of axes will be created using Pyplot
             show: show the figure on-screen
@@ -75,27 +76,14 @@ class DOSCollection(collections.abc.Sequence):
         Returns:
             Plotting axes. If "ax" was set, this is the same object.
         """
-
-        with SimplePlottingAxes(ax=ax, show=show, filename=filename) as ax:
-
-            if mplargs is None:
-                mplargs = {}
-
-            energies, all_y = self.sample_grid(npts,
-                                               xmin=xmin, xmax=xmax,
-                                               width=width, smearing=smearing)
-
-            all_labels = [DOSData.label_from_info(data.info) for data in self]
-
-            all_lines = ax.plot(energies, all_y.T, **mplargs)
-            for line, label in zip(all_lines, all_labels):
-                line.set_label(label)
-            ax.legend()
-
-            ax.set_xlim(left=min(energies), right=max(energies))
-            ax.set_ylim(bottom=0)
-
-        return ax
+        return self.sample_grid(npts,
+                                xmin=xmin, xmax=xmax,
+                                width=width, smearing=smearing
+                                ).plot(npts=npts,
+                                       xmin=xmin, xmax=xmax,
+                                       width=width, smearing=smearing,
+                                       ax=ax, show=show, filename=filename,
+                                       mplargs=mplargs)
 
     def sample_grid(self,
                     npts: int,
@@ -104,7 +92,7 @@ class DOSCollection(collections.abc.Sequence):
                     padding: float = 3,
                     width: float = 0.1,
                     smearing: str = 'Gauss',
-                    ) -> Tuple[Sequence[float], np.ndarray]:
+                    ) -> 'GridDOSCollection':
         """Sample the DOS data on an evenly-spaced energy grid
 
         Args:
@@ -115,8 +103,8 @@ class DOSCollection(collections.abc.Sequence):
                 chosen
             padding: If xmin/xmax is unspecified, default value will be padded
                 by padding * width to avoid cutting off peaks.
-            width: Width of broadening kernel, passed to self.sample()
-            smearing: selection of broadening kernel, passed to self.sample()
+            width: Width of broadening kernel, passed to self.sample_grid()
+            smearing: selection of broadening kernel, for self.sample_grid()
 
         Returns:
             (energy values, sampled DOS)
@@ -130,8 +118,11 @@ class DOSCollection(collections.abc.Sequence):
         if xmax is None:
             xmax = (max(max(data.get_energies()) for data in self)
                     + (padding * width))
-        energies = np.linspace(xmin, xmax, npts)
-        return energies, self.sample(energies, width=width, smearing=smearing)
+
+        return GridDOSCollection(
+            [data.sample_grid(npts, xmin=xmin, xmax=xmax, width=width,
+                              smearing=smearing)
+             for data in self])
 
     @classmethod
     def from_data(cls,
@@ -218,6 +209,7 @@ class DOSCollection(collections.abc.Sequence):
         return data
 
     D = TypeVar('D', bound=DOSData)
+
     @staticmethod
     def _select_to_list(dos_collection: Sequence[D],         # Bug in flakes
                         info_selection: Dict[str, str],      # misses 'D' def
@@ -409,6 +401,12 @@ class GridDOSCollection(DOSCollection):
             self._weights[i, :] = dos_data.get_weights()
             self._info.append(dos_data.info)
 
+    def get_energies(self) -> Sequence[float]:
+        return self._energies.copy()
+
+    def get_all_weights(self) -> Sequence[Sequence[float]]:
+        return self._weights.copy()
+
     def __len__(self) -> int:
         return self._weights.shape[0]
 
@@ -434,7 +432,7 @@ class GridDOSCollection(DOSCollection):
     def from_data(cls,
                   energies: Sequence[float],
                   weights: Sequence[Sequence[float]],
-                  info: Sequence[Info] = None) -> 'DOSCollection':
+                  info: Sequence[Info] = None) -> 'GridDOSCollection':
         """Create a GridDOSCollection from data with a common set of energies
 
         This convenience method may also be more efficient as it limits
@@ -528,3 +526,82 @@ class GridDOSCollection(DOSCollection):
             return type(self)([], energies=self._energies)
         else:
             return type(self)(matches)
+
+    def plot(self,
+             npts: int = 0,
+             xmin: float = None,
+             xmax: float = None,
+             width: float = None,
+             smearing: str = 'Gauss',
+             ax: 'matplotlib.axes.Axes' = None,
+             show: bool = False,
+             filename: str = None,
+             mplargs: dict = None) -> 'matplotlib.axes.Axes':
+        """Simple plot of collected DOS data, resampled onto a grid
+
+        If the special key 'label' is present in self.info, this will be set
+        as the label for the plotted line (unless overruled in mplargs). The
+        label is only seen if a legend is added to the plot (i.e. by calling
+        `ax.legend()`).
+
+        Args:
+            npts:
+                Number of points in resampled x-axis. If set to zero (default),
+                no resampling is performed and the stored data is plotted
+                directly.
+            xmin, xmax:
+                output data range; this limits the resampling range as well as
+                the plotting output
+            width: Width of broadening kernel, passed to self.sample()
+            smearing: selection of broadening kernel, passed to self.sample()
+            ax: existing Matplotlib axes object. If not provided, a new figure
+                with one set of axes will be created using Pyplot
+            show: show the figure on-screen
+            filename: if a path is given, save the figure to this file
+            mplargs: additional arguments to pass to matplotlib plot command
+                (e.g. {'linewidth': 2} for a thicker line).
+
+        Returns:
+            Plotting axes. If "ax" was set, this is the same object.
+        """
+
+        # Apply defaults if necessary
+        npts, width = GridDOSData._interpret_smearing_args(npts, width)
+
+        if npts:
+            assert isinstance(width, float)
+            dos = self.sample_grid(npts,
+                                   xmin=xmin, xmax=xmax,
+                                   width=width, smearing=smearing)
+        else:
+            dos = self
+
+        energies, all_y = dos._energies, dos._weights
+
+        all_labels = [DOSData.label_from_info(data.info) for data in self]
+
+        with SimplePlottingAxes(ax=ax, show=show, filename=filename) as ax:
+            self._plot_broadened(ax, energies, all_y, all_labels, mplargs)
+
+        return ax
+
+    @staticmethod
+    def _plot_broadened(ax: 'matplotlib.axes.Axes',
+                        energies: Sequence[float],
+                        all_y: np.ndarray,
+                        all_labels: Sequence[str],
+                        mplargs: Union[Dict, None]):
+        """Plot DOS data with labels to axes
+
+        This is separated into another function so that subclasses can
+        manipulate broadening, labels etc in their plot() method."""
+        if mplargs is None:
+            mplargs = {}
+
+        all_lines = ax.plot(energies, all_y.T, **mplargs)
+        for line, label in zip(all_lines, all_labels):
+            line.set_label(label)
+        ax.legend()
+
+        ax.set_xlim(left=min(energies), right=max(energies))
+        ax.set_ylim(bottom=0)
