@@ -1,9 +1,10 @@
-def test_bandstructure_json():
-    from ase.build import bulk
-    from ase.spectrum.band_structure import calculate_band_structure, BandStructure
-    from ase.io.jsonio import read_json
-    from ase.calculators.test import FreeElectrons
+from ase.build import bulk
+from ase.spectrum.band_structure import calculate_band_structure, BandStructure
+from ase.io.jsonio import read_json
+from ase.calculators.test import FreeElectrons
 
+
+def test_bandstructure_json(testdir):
     atoms = bulk('Au')
     lat = atoms.cell.get_bravais_lattice()
     path = lat.bandpath(npoints=100)
