@@ -1,7 +1,8 @@
-def test_bravais_hex():
-    import numpy as np
-    from ase.build import bulk
+import numpy as np
+from ase.build import bulk
 
+
+def test_bravais_hex():
     atoms = bulk('Ti')
     assert np.allclose(atoms.cell.angles(), [90, 90, 120])
     atoms.cell.get_bravais_lattice().name == 'HEX'
@@ -12,8 +13,3 @@ def test_bravais_hex():
     lat = cell.get_bravais_lattice()
     assert lat.name == 'HEX'
     assert np.allclose(lat.tocell().angles(), [90, 90, 120])
-
-    path120 = atoms.cell.bandpath()
-    path60 = cell.bandpath()
-    path120.write('path.120.json')
-    path60.write('path.60.json')
