@@ -1,8 +1,9 @@
-def test_molecule():
-    from ase.optimize import BFGS
-    from ase.atoms import Atoms
-    from ase.calculators.crystal import CRYSTAL
+from ase.optimize import BFGS
+from ase.atoms import Atoms
+from ase.calculators.crystal import CRYSTAL
 
+
+def test_molecule(testdir):
     with open('basis', 'w') as fd:
         fd.write("""6 4
     0 0 6 2.0 1.0
@@ -16,7 +17,7 @@ def test_molecule():
      3.665 -0.3959 0.2365
      0.7705 1.216 0.8606
     0 1 1 0.0 1.0
-     0.26 1.0 1.0 
+     0.26 1.0 1.0
     0 3 1 0.0 1.0
      0.8 1.0
     """)
@@ -35,8 +36,8 @@ def test_molecule():
                    ['tolinteg', '7 7 7 7 14'],
                    ['fmixing', '90']])
 
-    opt = BFGS(geom)
-    opt.run(fmax=0.05)
+    with BFGS(geom) as opt:
+        opt.run(fmax=0.05)
 
     final_energy = geom.get_potential_energy()
     assert abs(final_energy + 2047.34531091) < 1.0
