@@ -18,12 +18,12 @@ def test_dftb_relax_surface(factory):
     a = 5.40632280995384
     atoms = diamond100('Si', (1, 1, 6), a=a, vacuum=6., orthogonal=True,
                        periodic=True)
-    atoms.positions[-2:,2] -= 0.2
+    atoms.positions[-2:, 2] -= 0.2
     atoms.set_constraint(FixAtoms(indices=range(4)))
     atoms.calc = calc
 
-    dyn = BFGS(atoms, logfile='-')
-    dyn.run(fmax=0.1)
+    with BFGS(atoms, logfile='-') as dyn:
+        dyn.run(fmax=0.1)
 
     e = atoms.get_potential_energy()
     assert abs(e - -214.036907) < 1., e
