@@ -4,7 +4,6 @@ def test_water():
     from ase.optimize.lbfgs import LBFGS
     from ase.io import read
 
-
     # First test to make sure Gaussian works
     calc = Gaussian(xc='pbe', chk='water.chk', label='water')
     calc.clean()
@@ -13,8 +12,8 @@ def test_water():
                   positions=[(0, 0, 0), (1, 0, 0), (0, 1, 0)],
                   calculator=calc)
 
-    opt = LBFGS(water)
-    opt.run(fmax=0.05)
+    with LBFGS(water) as opt:
+        opt.run(fmax=0.05)
 
     forces = water.get_forces()
     energy = water.get_potential_energy()
