@@ -4,7 +4,7 @@ from pytest import mark
 
 
 @mark.calculator_lite
-def test_relax(KIM):
+def test_relax(KIM, testdir):
     """
     Test that a static relaxation that requires multiple neighbor list
     rebuilds can be carried out successfully.  This is verified by relaxing
@@ -20,7 +20,7 @@ def test_relax(KIM):
     calc = KIM("ex_model_Ar_P_Morse_07C")
     atoms.calc = calc
 
-    opt = BFGS(atoms, maxstep=0.04, alpha=70.0, logfile=None)
-    opt.run(fmax=0.01)  # eV/angstrom
+    with BFGS(atoms, maxstep=0.04, alpha=70.0, logfile=None) as opt:
+        opt.run(fmax=0.01)  # eV/angstrom
 
     assert np.isclose(atoms.get_potential_energy(), energy_ref, atol=0.05)
