@@ -1,7 +1,7 @@
 import pytest
 from numpy.testing import assert_allclose
 from ase.cluster.icosahedron import Icosahedron
-from ase.data import atomic_numbers,  atomic_masses
+from ase.data import atomic_numbers, atomic_masses
 from ase.optimize import LBFGS
 
 
@@ -30,15 +30,17 @@ def test_Ar_minimize(factory, ar_nc, params):
 
         assert_allclose(ar_nc.get_potential_energy(), -0.468147667942117,
                         atol=1e-4, rtol=1e-4)
-        assert_allclose(ar_nc.get_forces(), calc.calculate_numerical_forces(ar_nc),
+        assert_allclose(ar_nc.get_forces(),
+                        calc.calculate_numerical_forces(ar_nc),
                         atol=1e-4, rtol=1e-4)
 
-        dyn = LBFGS(ar_nc, force_consistent=False)
-        dyn.run(fmax=1E-6)
+        with LBFGS(ar_nc, force_consistent=False) as dyn:
+            dyn.run(fmax=1E-6)
 
         assert_allclose(ar_nc.get_potential_energy(), -0.4791815886953914,
                         atol=1e-4, rtol=1e-4)
-        assert_allclose(ar_nc.get_forces(), calc.calculate_numerical_forces(ar_nc),
+        assert_allclose(ar_nc.get_forces(),
+                        calc.calculate_numerical_forces(ar_nc),
                         atol=1e-4, rtol=1e-4)
 
 
@@ -69,5 +71,6 @@ def test_Ar_minimize_multistep(factory, ar_nc, params):
 
         assert_allclose(ar_nc.get_potential_energy(), -0.4791815887032201,
                         atol=1e-4, rtol=1e-4)
-        assert_allclose(ar_nc.get_forces(), calc.calculate_numerical_forces(ar_nc),
+        assert_allclose(ar_nc.get_forces(),
+                        calc.calculate_numerical_forces(ar_nc),
                         atol=1e-4, rtol=1e-4)
