@@ -56,14 +56,17 @@ def test_ch4(tmp_path, spec):
 
 
 calc = pytest.mark.calculator
+filterwarnings = pytest.mark.filterwarnings
 
 
 @pytest.mark.calculator_lite
 @calc('abinit', ecut=300, chksymbreak=0, toldfe=1e-4)
+@calc('aims')
 @calc('cp2k')
 @calc('espresso', ecutwfc=300 / Ry)
 @calc('gpaw', symmetry='off', mode='pw', txt='gpaw.txt', mixer={'beta': 0.6},
-      marks=pytest.mark.filterwarnings('ignore:.*?ignore_bad_restart_file'))
+      marks=[filterwarnings('ignore:.*?ignore_bad_restart_file'),
+             filterwarnings('ignore:convert_string_to_fd')])
 @calc('nwchem')
 @calc('octopus', Spacing='0.4 * angstrom')
 @calc('openmx')
