@@ -9,13 +9,13 @@ def test_gulp_opt():
     atoms = molecule('H2O')
     atoms1 = atoms.copy()
     atoms1.calc = GULP(library='reaxff.lib')
-    opt1 = BFGS(atoms1)
-    opt1.run(fmax=0.005)
+    with BFGS(atoms1) as opt1:
+        opt1.run(fmax=0.005)
 
     atoms2 = atoms.copy()
     calc2 = GULP(keywords='opti conp', library='reaxff.lib')
-    opt2 = calc2.get_optimizer(atoms2)
-    opt2.run()
+    with calc2.get_optimizer(atoms2) as opt2:
+        opt2.run()
 
     print(np.abs(opt1.atoms.positions - opt2.atoms.positions))
     assert np.abs(opt1.atoms.positions - opt2.atoms.positions).max() < 1e-5
@@ -26,13 +26,13 @@ def test_gulp_opt():
     atoms1.calc = GULP(keywords='conp gradient stress_out',
                        library='reaxff_general.lib')
     atoms1f = ExpCellFilter(atoms1)
-    opt1 = BFGS(atoms1f)
-    opt1.run(fmax=0.005)
+    with BFGS(atoms1f) as opt1:
+        opt1.run(fmax=0.005)
 
     atoms2 = atoms.copy()
     calc2 = GULP(keywords='opti conp', library='reaxff_general.lib')
-    opt2 = calc2.get_optimizer(atoms2)
-    opt2.run()
+    with calc2.get_optimizer(atoms2) as opt2:
+        opt2.run()
 
     print(np.abs(opt1.atoms.positions - opt2.atoms.positions))
     assert np.abs(opt1.atoms.positions - opt2.atoms.positions).max() < 1e-5
