@@ -3,16 +3,14 @@ def test_orca():
     from ase.atoms import Atoms
     from ase.calculators.orca import ORCA
 
-
     atoms = Atoms('OHH',
                   positions=[(0, 0, 0), (1, 0, 0), (0, 1, 0)])
 
     atoms.calc = ORCA(label='water',
                       orcasimpleinput='BLYP def2-SVP')
 
-
-    opt = BFGS(atoms)
-    opt.run(fmax=0.05)
+    with BFGS(atoms) as opt:
+        opt.run(fmax=0.05)
 
     final_energy = atoms.get_potential_energy()
     print(final_energy)
