@@ -5,7 +5,8 @@ from ase.build import molecule
 from ase.test.factories import ObsoleteFactoryWrapper
 
 parameters = {
-    'aims': dict(sc_accuracy_rho=5.e-3, sc_accuracy_forces=1e-4, xc='LDA'),
+    'aims': dict(sc_accuracy_rho=5.e-3, sc_accuracy_forces=1e-4, xc='LDA',
+                 kpts=(1, 1, 1)),
     'crystal': dict(basis='sto-3g'),
     'gamess_us': dict(label='test_traj'),
     #'elk': dict(tasks=0, rgkmax=5.0, epsengy=1.0, epspot=1.0, tforce=True,
@@ -23,12 +24,12 @@ calc = pytest.mark.calculator
 # Deprecated keyword, remove this once things are resolved
 @calc('abinit', 'cp2k', 'emt')
 @calc('vasp', xc='lda', prec='low')
-def test_h2_traj(factory):
+def test_h2_traj(factory, testdir):
     run(factory)
 
 
 @pytest.mark.parametrize('name', sorted(parameters))
-def test_h2_traj_old(name):
+def test_h2_traj_old(name, testdir):
     factory = ObsoleteFactoryWrapper(name)
     run(factory)
 
@@ -38,6 +39,7 @@ def run(factory):
     par = parameters.get(name, {})
     h2 = molecule('H2')
     h2.center(vacuum=2.0)
+    h2.pbc = True
     h2.calc = factory.calc(**par)
     e = h2.get_potential_energy()
     assert not h2.calc.calculation_required(h2, ['energy'])
