@@ -1,8 +1,10 @@
-def test_ts09():
-    from ase import io
-    from ase.calculators.vdwcorrection import vdWTkatchenko09prl
-    from ase.calculators.emt import EMT
-    from ase.build import bulk
+from ase import io
+from ase.calculators.vdwcorrection import vdWTkatchenko09prl
+from ase.calculators.emt import EMT
+from ase.build import bulk
+
+
+def test_ts09(testdir):
 
     # fake objects for the test
     class FakeHirshfeldPartitioning:
