@@ -1,5 +1,7 @@
+import os
 import pytest
 from ase import Atoms
+from ase.calculators.vasp import Vasp
 
 
 @pytest.fixture
@@ -34,3 +36,13 @@ def mock_vasp_calculate(mocker):
     # calculations aren't accidentally launched
     mocker.patch('ase.calculators.vasp.Vasp._run', _mock_run)
     yield
+
+
+@pytest.fixture
+def clear_vasp_envvar(monkeypatch):
+    """Clear the environment variables which can be used to launch
+    a VASP calculation."""
+    for envvar in Vasp.env_commands:
+        monkeypatch.delenv(envvar, raising=False)
+        assert envvar not in os.environ
+    yield
