@@ -8,8 +8,8 @@ def check_potcar(setups, filename='POTCAR'):
     """Return true if labels in setups are found in POTCAR"""
 
     pp = []
-    with open(filename, 'r') as f:
-        for line in f:
+    with open(filename, 'r') as fd:
+        for line in fd:
             if 'TITEL' in line.split():
                 pp.append(line.split()[3])
     for setup in setups:
