@@ -14,7 +14,7 @@ from ase.io import write
     ],
     ids=lambda atoms: f'{atoms.cell.rank}-dim',
 )
-def file(request):
+def file(request, testdir):
     atoms = request.param
     file = f'atoms.{atoms.cell.rank}dim.traj'
     write(file, atoms)
