@@ -17,7 +17,7 @@ def build_layer():
     ],
     ids=['layer', 'bulk'],
 )
-def file(request):
+def file(request, testdir):
     atoms, dimtype = request.param
     file = f'atoms.{dimtype}.cfg'
     write(file, atoms)
