@@ -8,7 +8,7 @@ from ase.build import fcc111, add_adsorbate
 
 
 @pytest.mark.parametrize('wrap', [False, True])
-def test_au111(wrap):
+def test_au111(wrap, testdir):
     zpos = cos(134.3 / 2.0 * pi / 180.0) * 1.197
     xpos = sin(134.3 / 2.0 * pi / 180.0) * 1.19
     co2 = Atoms('COO', positions=[(-xpos + 1.2, 0, -zpos),
