@@ -1,11 +1,9 @@
-from pathlib import Path
 import numpy as np
 from ase.build import bulk
 from ase.io.aims import read_aims as read
 from ase.io.aims import parse_geometry_lines
 from pytest import approx
 
-parent = Path(__file__).parent
 format = "aims"
 
 atoms = bulk("Si")
@@ -56,6 +54,7 @@ def test_scaled_wrapped(atoms=atoms):
             new_atoms.positions,
         )
 
+
 sample_geometry_1 = """\
 lattice_vector 4.5521460059804628 0.0000000000000000 0.0000000000000000
 lattice_vector -2.2760730029902314 3.9422740829149499 0.0000000000000000 # Dummy comment
@@ -88,7 +87,7 @@ atom 0.3333333333333333 0.6666666666666666 0.2650974399999999 I
     initial_moment 1
 """
 
-expected_symbols = ['Pb','I','I']
+expected_symbols = ['Pb', 'I', 'I']
 expected_scaled_positions = np.array([
     [0.0000000000000000, 0.0000000000000000, 0.0000000000000000],
     [0.6666666666666666, 0.3333333333333333, 0.7349025600000000],
@@ -105,14 +104,14 @@ expected_lattice_vectors = np.array([
 
 def test_parse_geometry_lines():
     lines = sample_geometry_1.splitlines()
-    atoms = parse_geometry_lines(lines,'sample_geometry_1.in')
+    atoms = parse_geometry_lines(lines, 'sample_geometry_1.in')
     assert all(atoms.symbols == expected_symbols)
     assert atoms.get_scaled_positions() == approx(expected_scaled_positions)
     assert atoms.get_cell()[:] == approx(expected_lattice_vectors)
     assert all(atoms.pbc)
 
     lines = sample_geometry_2.splitlines()
-    atoms = parse_geometry_lines(lines,'sample_geometry_2.in')
+    atoms = parse_geometry_lines(lines, 'sample_geometry_2.in')
     assert all(atoms.symbols == expected_symbols)
     assert atoms.get_scaled_positions() == approx(expected_scaled_positions)
     assert atoms.get_initial_charges() == approx(expected_charges)
