@@ -24,8 +24,8 @@ def test_xsd_bond():
     # Read and see if the atom information and bond information matches.
     AtomIdsToBondIds = OrderedDict()
     BondIdsToConnectedAtomIds = OrderedDict()
-    with open('xsd_test_CH4.xsd', 'r') as f:
-        for i, line in enumerate(f):
+    with open('xsd_test_CH4.xsd', 'r') as fd:
+        for i, line in enumerate(fd):
             if '<Atom3d ' in line:
                 AtomId = int(re.search(r'ID="(.*?)"', line).group(1))
                 ConnectedBondIds = [
