@@ -21,14 +21,14 @@ def test_idealgas():
     MaxwellBoltzmannDistribution(atoms, temperature_K=md_temp, rng=rng)
     print("Temperature: {} K".format(atoms.get_temperature()))
 
-    md = VelocityVerlet(atoms, timestep=0.1)
-    for i in range(5):
-        md.run(5)
-        stress = atoms.get_stress(include_ideal_gas=True)
-        stresses = atoms.get_stresses(include_ideal_gas=True)
-        assert stresses.mean(0) == pytest.approx(stress)
-        pressure = -stress[:3].sum() / 3
-        pV = pressure * atoms.cell.volume
-        NkT = natoms * kB * atoms.get_temperature()
-        print(f"pV = {pV}  NkT = {NkT}")
-        assert pV == pytest.approx(NkT, abs=1e-6)
+    with VelocityVerlet(atoms, timestep=0.1) as md:
+        for i in range(5):
+            md.run(5)
+            stress = atoms.get_stress(include_ideal_gas=True)
+            stresses = atoms.get_stresses(include_ideal_gas=True)
+            assert stresses.mean(0) == pytest.approx(stress)
+            pressure = -stress[:3].sum() / 3
+            pV = pressure * atoms.cell.volume
+            NkT = natoms * kB * atoms.get_temperature()
+            print(f"pV = {pV}  NkT = {NkT}")
+            assert pV == pytest.approx(NkT, abs=1e-6)
