@@ -2,7 +2,7 @@ from ase.build import molecule
 from ase.neb import NEB, idpp_interpolate
 
 
-def test_idpp():
+def test_idpp(testdir):
     initial = molecule('C2H6')
     final = initial.copy()
     final.positions[2:5] = initial.positions[[3, 4, 2]]
