@@ -7,7 +7,7 @@ from ase.io import read
 from ase.visualize import view
 
 
-def test_replay():
+def test_replay(testdir):
     # Distance between Cu atoms on a (100) surface:
     d = 3.6 / sqrt(2)
     a = Atoms('Cu',
