@@ -7,6 +7,14 @@ from ase.utils.plotting import SimplePlottingAxes
 from ase.visualize.plot import plot_atoms
 
 
+def test_matplotlib_plot_info_occupancies(plt):
+    slab = FaceCenteredCubic('Au')
+    slab.info['occupancy'] = {'0': {'Au': 1}}
+    fig, ax = plt.subplots()
+    plot_atoms(slab, ax, show_unit_cell=0)
+    assert len(ax.patches) == len(slab)
+
+
 def test_matplotlib_plot(plt):
     slab = FaceCenteredCubic('Au', size=(2, 2, 2))
 
@@ -15,7 +23,6 @@ def test_matplotlib_plot(plt):
                show_unit_cell=0)
 
     assert len(ax.patches) == len(slab)
-    print(ax)
 
 
 class TestPlotManager:
@@ -36,7 +43,7 @@ class TestPlotManager:
 
         assert np.allclose(ax.lines[0].get_xydata().transpose(), xy_data)
 
-    def test_plot_manager_axis_file(self, xy_data, figure):
+    def test_plot_manager_axis_file(self, testdir, xy_data, figure):
         filename = 'plot.png'
         x, y = xy_data
         ax = figure.add_subplot(111)
