@@ -1,8 +1,8 @@
 """
 Test Placzek type resonant Raman implementations
 """
-import os
 import pytest
+from pathlib import Path
 
 from ase.parallel import parprint, world
 from ase.vibrations.vibrations import Vibrations
@@ -13,7 +13,7 @@ from ase.calculators.h2morse import (H2Morse,
                                      H2MorseExcitedStatesCalculator)
 
 
-def test_summary():
+def test_summary(testdir):
     atoms = H2Morse()
     rmc = ResonantRamanCalculator(atoms, H2MorseExcitedStatesCalculator)
     rmc.run()
@@ -22,22 +22,29 @@ def test_summary():
     pz.summary(1.)
 
 
-def test_names():
+def test_names(testdir):
     """Test different gs vs excited name. Tests also default names."""
     # do a Vibrations calculation first
     atoms = H2Morse()
-    Vibrations(atoms).run()
-    assert os.path.isfile('vib.0x-.pckl')
+    vib = Vibrations(atoms)
+    vib.run()
+    assert '0x-' in vib.cache
 
     # do a Resonant Raman calculation
     rmc = ResonantRamanCalculator(atoms, H2MorseExcitedStatesCalculator,
                                   verbose=True)
     rmc.run()
+
+    # excitation files should reside in the same directory as cache files
+    assert (Path(rmc.name) / ('ex.eq' + rmc.exext)).is_file()
+
+    # XXX does this still make sense?
     # remove the corresponding pickle file,
     # then Placzek can not anymore use it for vibrational properties
-    assert os.path.isfile('raman.0x-.pckl')
-    os.remove('raman.0x-.pckl')  # make sure this is not used
-        
+    key = '0x-'
+    assert key in rmc.cache
+    del rmc.cache[key]  # make sure this is not used
+
     om = 1
     gam = 0.1
     pz = Placzek(atoms, H2MorseExcitedStates,
@@ -47,65 +54,66 @@ def test_names():
 
     # check that work was distributed correctly
     assert len(pz.myindices) <= -(-6 // world.size)
-    
 
-def test_overlap():
+
+def test_overlap(testdir):
     """Test equality with and without overlap"""
     atoms = H2Morse()
     name = 'rrmorse'
     nstates = 3
-    rmc = ResonantRamanCalculator(atoms, H2MorseExcitedStatesCalculator,
-                                  exkwargs={'nstates': nstates},
-                                  overlap=lambda x, y: x.overlap(y),
-                                  name=name, txt='-')
-    rmc.run()
+    with ResonantRamanCalculator(atoms, H2MorseExcitedStatesCalculator,
+                                 exkwargs={'nstates': nstates},
+                                 overlap=lambda x, y: x.overlap(y),
+                                 name=name, txt='-') as rmc:
+        rmc.run()
 
     om = 1
     gam = 0.1
-    po = Profeta(atoms, H2MorseExcitedStates,
-                 exkwargs={'nstates': nstates}, approximation='Placzek',
-                 overlap=True, name=name, txt='-')
-    poi = po.get_absolute_intensities(omega=om, gamma=gam)[-1]
 
-    pr = Profeta(atoms, H2MorseExcitedStates,
+    with Profeta(atoms, H2MorseExcitedStates,
                  exkwargs={'nstates': nstates}, approximation='Placzek',
-                 name=name, txt=None)
-    pri = pr.get_absolute_intensities(omega=om, gamma=gam)[-1]
+                 overlap=True, name=name, txt='-') as po:
+        poi = po.get_absolute_intensities(omega=om, gamma=gam)[-1]
+
+    with Profeta(atoms, H2MorseExcitedStates,
+                 exkwargs={'nstates': nstates}, approximation='Placzek',
+                 name=name, txt=None) as pr:
+        pri = pr.get_absolute_intensities(omega=om, gamma=gam)[-1]
 
     print('overlap', pri, poi, poi / pri)
     assert pri == pytest.approx(poi, 1e-4)
 
 
-def test_compare_placzek_implementation_intensities():
+def test_compare_placzek_implementation_intensities(testdir):
     """Intensities of different Placzek implementations
     should be similar"""
     atoms = H2Morse()
     name = 'placzek'
-    rmc = ResonantRamanCalculator(atoms, H2MorseExcitedStatesCalculator,
+    with ResonantRamanCalculator(atoms, H2MorseExcitedStatesCalculator,
                                   overlap=lambda x, y: x.overlap(y),
-                                  name=name, txt='-')
-    rmc.run()
+                                  name=name, txt='-') as rmc:
+        rmc.run()
 
     om = 1
     gam = 0.1
 
-    pz = Placzek(atoms, H2MorseExcitedStates,
-                 name=name, txt=None)
-    pzi = pz.get_absolute_intensities(omega=om, gamma=gam)[-1]
+    with Placzek(atoms, H2MorseExcitedStates,
+                 name=name, txt=None) as pz:
+        pzi = pz.get_absolute_intensities(omega=om, gamma=gam)[-1]
     print(pzi, 'Placzek')
 
     # Profeta using frozenset
-    pr = Profeta(atoms, H2MorseExcitedStates,
+    with Profeta(atoms, H2MorseExcitedStates,
                  approximation='Placzek',
-                 name=name, txt=None)
-    pri = pr.get_absolute_intensities(omega=om, gamma=gam)[-1]
+                 name=name, txt=None) as pr:
+        pri = pr.get_absolute_intensities(omega=om, gamma=gam)[-1]
     print(pri, 'Profeta using frozenset')
     assert pzi == pytest.approx(pri, 1e-3)
-    
+
     # Profeta using overlap
-    pr = Profeta(atoms, H2MorseExcitedStates,
+    with Profeta(atoms, H2MorseExcitedStates,
                  approximation='Placzek', overlap=True,
-                 name=name, txt=None)
-    pro = pr.get_absolute_intensities(omega=om, gamma=gam)[-1]
+                 name=name, txt=None) as pr:
+        pro = pr.get_absolute_intensities(omega=om, gamma=gam)[-1]
     print(pro, 'Profeta using overlap')
     assert pro == pytest.approx(pri, 1e-3)
