@@ -11,13 +11,13 @@ from ase.calculators.h2morse import (H2Morse,
                                      H2MorseExcitedStatesCalculator)
 
 
-def test_compare_placzek_albrecht_intensities():
+def test_compare_placzek_albrecht_intensities(testdir):
     atoms = H2Morse()
     name = 'rrmorse'
-    rmc = ResonantRamanCalculator(atoms, H2MorseExcitedStatesCalculator,
-                                  overlap=lambda x, y: x.overlap(y),
-                                  name=name, txt='-')
-    rmc.run()
+    with ResonantRamanCalculator(atoms, H2MorseExcitedStatesCalculator,
+                                 overlap=lambda x, y: x.overlap(y),
+                                 name=name, txt='-') as rmc:
+        rmc.run()
 
     om = 1
     gam = 0.1
@@ -25,14 +25,14 @@ def test_compare_placzek_albrecht_intensities():
 
     """Albrecht A and P-P are approximately equal"""
 
-    pr = Profeta(atoms, H2MorseExcitedStates,
+    with Profeta(atoms, H2MorseExcitedStates,
                  name=name, overlap=True,
-                 approximation='p-p', txt=None)
-    pri = pr.get_absolute_intensities(omega=om, gamma=gam)[-1]
-    al = Albrecht(atoms, H2MorseExcitedStates,
+                 approximation='p-p', txt=None) as pr:
+        pri = pr.get_absolute_intensities(omega=om, gamma=gam)[-1]
+    with Albrecht(atoms, H2MorseExcitedStates,
                   name=name, overlap=True,
-                  approximation='Albrecht A', txt=None)
-    ali = al.get_absolute_intensities(omega=om, gamma=gam)[-1]
+                  approximation='Albrecht A', txt=None) as al:
+        ali = al.get_absolute_intensities(omega=om, gamma=gam)[-1]
     print('pri, ali', pri, ali)
     assert pri == pytest.approx(ali, 1e-2)
 
