@@ -13,7 +13,6 @@ python3 -m venv venv
 pip install sphinx-rtd-theme pillow
 git clone http://gitlab.com/ase/ase.git
 cd ase
-git checkout {branch}
 pip install .
 python setup.py sdist
 cd doc
@@ -21,38 +20,34 @@ make
 mv build/html ase-web-page"""
 
 
-def build(branch='master'):
-    root = Path(f'/tmp/ase-docs-{branch}')
+def build():
+    root = Path('/tmp/ase-docs')
     if root.is_dir():
         sys.exit('Locked')
     root.mkdir()
     os.chdir(root)
-    cmds2 = ' && '.join(cmds.format(branch=branch).splitlines())
+    cmds2 = ' && '.join(cmds.splitlines())
     p = subprocess.run(cmds2, shell=True)
     if p.returncode == 0:
         status = 'ok'
     else:
         print('FAILED!', file=sys.stdout)
         status = 'error'
-    f = root.with_name(f'ase-docs-{branch}-{status}')
+    f = root.with_name(f'ase-docs-{status}')
     if f.is_dir():
         shutil.rmtree(f)
     root.rename(f)
     return status
 
 
-def build_both():
-    assert build('master') == 'ok'
-    assert build('web-page') == 'ok'
+def build_all():
+    assert build() == 'ok'
     tar = next(
-        Path('/tmp/ase-docs-master-ok/ase/dist/').glob('ase-*.tar.gz'))
-    master = Path('/tmp/ase-docs-master-ok/ase/doc/ase-web-page')
-    webpage = Path('/tmp/ase-docs-web-page-ok/ase/doc/ase-web-page')
+        Path('/tmp/ase-docs--ok/ase/dist/').glob('ase-*.tar.gz'))
+    webpage = Path('/tmp/ase-docs-ok/ase/doc/ase-web-page')
     home = Path.home() / 'web-pages'
     cmds = ' && '.join(
-        [f'cp -rp {master} {webpage}/dev',
-         f'cp {tar} {webpage}',
-         f'cp {tar} {webpage}/dev',
+        [f'cp {tar} {webpage}',
          f'find {webpage} -name install.html | '
          f'xargs sed -i s/snapshot.tar.gz/{tar.name}/g',
          f'cd {webpage.parent}',
@@ -62,5 +57,4 @@ def build_both():
 
 
 if __name__ == '__main__':
-    # build()
-    build_both()
+    build_all()
