@@ -59,7 +59,7 @@ def main():
     p = argparse.ArgumentParser(description='Generate new release of ASE.',
                                 epilog='Run from the root directory of ASE.')
     p.add_argument('version', nargs=1,
-                 help='version number for new release')
+                   help='version number for new release')
     p.add_argument('nextversion', nargs=1,
                    help='development version after release')
     p.add_argument('--clean', action='store_true',
@@ -225,13 +225,13 @@ News
     py('setup.py sdist > setup_sdist.log')
     py('setup.py bdist_wheel > setup_bdist_wheel3.log')
     bash('gpg --armor --yes --detach-sign dist/ase-{}.tar.gz'.format(version))
-    git('checkout -b web-page')
-    git('branch --set-upstream-to=origin/web-page')
-    git('checkout {}'.format(branchname))
-    update_version(next_devel_version)
-    git('add {}'.format(versionfile))
-    git('branch --set-upstream-to=master')
-    git('commit -m "bump version number to {}"'.format(next_devel_version))
+    # git('checkout -b web-page')
+    # git('branch --set-upstream-to=origin/web-page')
+    # git('checkout {}'.format(branchname))
+    # update_version(next_devel_version)
+    # git('add {}'.format(versionfile))
+    # git('branch --set-upstream-to=master')
+    # git('commit -m "bump version number to {}"'.format(next_devel_version))
 
     print()
     print('Automatic steps done.')
