@@ -190,17 +190,18 @@ class FranckCondonRecursive:
             sum += m * (m - 1)
         with np.errstate(divide='ignore', invalid='ignore'):
             return np.where(S == 0, 0,
-                (np.exp(-S) * S**(m - 1) / delta * (S - m) * sum *
-                 self.factorial.inv(m)))
+                            (np.exp(-S) * S**(m - 1) / delta
+                             * (S - m) * sum * self.factorial.inv(m)))
 
     def direct0mm3(self, m, delta):
         S = delta**2 / 2.
         with np.errstate(divide='ignore', invalid='ignore'):
-            return np.where(S == 0, 0,
+            return np.where(
+                S == 0, 0,
                 (np.exp(-S) * S**(m - 1) / delta * np.sqrt(12.) *
-                 (S**3 / 6. - m * S**2 / 2 +
-                  m * (m - 1) * S / 2. - m * (m - 1) * (m - 2) / 6) *
-                 self.factorial.inv(m)))
+                 (S**3 / 6. - m * S**2 / 2
+                  + m * (m - 1) * S / 2. - m * (m - 1) * (m - 2) / 6)
+                 * self.factorial.inv(m)))
 
 
 class FranckCondon:
@@ -256,20 +257,37 @@ class FranckCondon:
 
         return S_V, frequencies
 
-    def get_Franck_Condon_factors(self, order, temp, forces):
+    def get_Franck_Condon_factors(self, temperature, forces, order=1):
         """Return FC factors and corresponding frequencies up to given order.
 
-        order= number of quanta taken into account
-        T= temperature in K. Vibronic levels are occupied by a
-        Boltzman distribution.
-        forces= forces on atoms in the exited electronic state"""
+        Parameters
+        ----------
+        temperature: float
+          Temperature in K. Vibronic levels are occupied by a
+          Boltzman distribution.
+        forces: array
+          Forces on atoms in the exited electronic state
+        order: int
+          number of quanta taken into account, default
 
+        Returns
+        --------
+        FC: 3 entry list
+          FC[0] = FC factors for 0-0 and +-1 vibrational quantum
+          FC[1] = FC factors for +-2 vibrational quanta
+          FC[2] = FC factors for combinations
+        frequencies: 3 entry list
+          frequencies[0] correspond to FC[0]
+          frequencies[1] correspond to FC[1]
+          frequencies[2] correspond to FC[2]
+        """
         S, f = self.get_Huang_Rhys_factors(forces)
+        assert order > 0
         n = order + 1
-        T = temp
+        T = temperature
         freq = np.array(f)
 
-        # frequencies
+        # frequencies and their multiples
         freq_n = [[] * i for i in range(n - 1)]
         freq_neg = [[] * i for i in range(n - 1)]
 
@@ -284,7 +302,7 @@ class FranckCondon:
 
         indices2 = []
         for i, y in enumerate(freq):
-            ind = [j for j, x in enumerate(freq_nn) if x % y == 0]
+            ind = [j for j, x in enumerate(freq_nn) if y == 0 or x % y == 0]
             indices2.append(ind)
         indices2 = [x for x in chain(*indices2)]
         freq_nn = np.delete(freq_nn, indices2)
@@ -380,10 +398,4 @@ class FranckCondon:
 
         FC[2] = FC_nn
 
-        """Returned are two 3-dimensional lists. First inner list contains
-frequencies and FC-factors of vibrations exited with |1| quanta and
-the 0-0 transition.
-        Second list contains frequencies and FC-factors from higher
-quanta exitations. Third list are combinations of two normal modes
-(including combinations of higher quanta exitations). """
         return FC, frequencies
