@@ -19,7 +19,7 @@ log_calc = LoggingCalculator(EMT())
 for precon, label in [(None, 'None'), (Exp(A=3, mu=1.0), 'Exp(A=3)')]:
     log_calc.label = label
     atoms = a0.copy()
-    atoms.set_calculator(log_calc)
+    atoms.calc = log_calc
     opt = PreconLBFGS(atoms, precon=precon, use_armijo=True)
     opt.run(fmax=1e-3)
 
