@@ -25,12 +25,13 @@ for i in range(len(cosb3)):
             bondatoms.append((i, j))
 
 # Create nice-looking image using povray
-io.write('spacegroup-cosb3.pov', cosb3,
-         transparent=False,
-         run_povray=True,
-         camera_type='perspective',
-         canvas_width=320,
-         radii=0.4,
-         rotation='90y',
-         bondlinewidth=0.07,
-         bondatoms=bondatoms)
+renderer = io.write('spacegroup-cosb3.pov', cosb3,
+                    rotation='90y',
+                    radii=0.4,
+                    povray_settings=dict(transparent=False,
+                                         camera_type='perspective',
+                                         canvas_width=320,
+                                         bondlinewidth=0.07,
+                                         bondatoms=bondatoms))
+
+renderer.render()
