@@ -1,5 +1,7 @@
 # creates: cu1o.png, cu2o.png, cu3o.png
 import os
+import runpy
+
 from ase.io import read, write
 from ase.cli.main import main
 from ase.db import connect
@@ -9,12 +11,8 @@ for name in ['bulk.db', 'ads.db', 'refs.db']:
         os.remove(name)
 
 # Run the tutorial:
-with open('bulk.py') as fd:
-    exec(fd.read())
-with open('ads.py') as fd:
-    exec(fd.read())
-with open('refs.py') as fd:
-    exec(fd.read())
+for filename in ['bulk.py', 'ads.py', 'refs.py']:
+    runpy.run_path(filename)
 
 for cmd in ['ase db ads.db ads=clean --insert-into refs.db',
             'ase db ads.db ads=clean --delete --yes',
@@ -22,16 +20,15 @@ for cmd in ['ase db ads.db ads=clean --insert-into refs.db',
             'ase db ads.db pbc=FFF --delete --yes']:
     main(args=cmd.split()[1:])
 
-with open('ea.py') as fd:
-    exec(fd.read())
+runpy.run_path('ea.py')
 
 # Create the figures:
 for n in [1, 2, 3]:
     a = read('ads.db@Cu{}O'.format(n))[0]
     a *= (2, 2, 1)
-    write('cu{}o.pov'.format(n), a,
-          rotation='-80x',
-          run_povray=True)
+    renderer = write('cu{}o.pov'.format(n), a,
+                     rotation='-80x')
+    renderer.render()
 
 # A bit of testing:
 row = connect('ads.db').get(surf='Pt', layers=3, ads='O')
