@@ -1,4 +1,5 @@
 import numpy as np
+import matplotlib.pyplot as plt
 from ase.phasediagram import PhaseDiagram
 from ase.db import connect
 from ase.io import write
@@ -13,7 +14,9 @@ for dct in dcts:
     refs.append((dct.formula, -dct.raw_score))
 
 pd = PhaseDiagram(refs)
-pd.plot(only_label_simplices=True)
+ax = pd.plot(show=not True,  # set to True to show plot
+             only_label_simplices=True)
+plt.savefig('hull.png')
 
 # View the simplices of the convex hull
 simplices = []
