@@ -14,7 +14,7 @@ if use_asap:
 else:
     from ase.calculators.emt import EMT
     size = 3
-    
+
 # Set up a crystal
 atoms = FaceCenteredCubic(directions=[[1, 0, 0], [0, 1, 0], [0, 0, 1]],
                           symbol="Cu",
@@ -25,7 +25,7 @@ atoms = FaceCenteredCubic(directions=[[1, 0, 0], [0, 1, 0], [0, 0, 1]],
 atoms.calc = EMT()
 
 # Set the momenta corresponding to T=300K
-MaxwellBoltzmannDistribution(atoms, 300 * units.kB)
+MaxwellBoltzmannDistribution(atoms, temperature_K=300)
 
 # We want to run MD with constant energy using the VelocityVerlet algorithm.
 dyn = VelocityVerlet(atoms, 5 * units.fs)  # 5 fs time step.
@@ -38,6 +38,7 @@ def printenergy(a=atoms):  # store a reference to atoms in the definition.
     print('Energy per atom: Epot = %.3feV  Ekin = %.3feV (T=%3.0fK)  '
           'Etot = %.3feV' % (epot, ekin, ekin / (1.5 * units.kB), epot + ekin))
 
+
 # Now run the dynamics
 dyn.attach(printenergy, interval=10)
 printenergy()
